@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   $Id: H01_zaratan.c,v 1.1 2002/02/11 20:20:09 alor Exp $
+   $Id: H01_zaratan.c,v 1.2 2002/02/22 19:48:56 alor Exp $
 */
 
 #include "../../src/include/ec_main.h"
@@ -85,7 +85,7 @@ int Fake_Host(void);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops zaratan_ops = {
    ettercap_version: VERSION,
    plug_info:        "Broker/redirector for GRE tunnels",
    plug_version:     10,
@@ -101,7 +101,7 @@ int Plugin_Init(void *params)
    sock = Inet_OpenRawSock(Options.netiface);
    Inet_GetIfaceInfo(Options.netiface, NULL, MyMAC, NULL, NULL);
 
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &zaratan_ops);
 }
 
 int Plugin_Fini(void *params)
