@@ -18,11 +18,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: basilisk.c,v 1.4 2002/02/22 19:48:56 alor Exp $
+    $Id: basilisk.c,v 1.5 2002/05/07 22:04:14 alor Exp $
 */
 
 #include <stdlib.h>
-#include <fcntl.h>
 #include <unistd.h>
 #include <sys/time.h>
 
@@ -67,7 +66,8 @@ int Plugin_Fini(void *params)
 int basilisk(void *dummy)
 {
    int sock, MTU, len=0, hnumb, i, j, notrecv=1;
-   char *ReceivedS, *ReceivedD, *MACHosts, *pck;
+   char *ReceivedS, *ReceivedD, *MACHosts;
+   struct recv_packet recvpck;
    u_long MyIP, SpoofIP, *Hosts;
    ETH_header *eth;
    IP_header  *ip;
@@ -92,28 +92,23 @@ int basilisk(void *dummy)
    sock = Inet_OpenRawSock(Options.netiface);
    Inet_GetIfaceInfo(Options.netiface, &MTU, MyMAC, &MyIP, NULL);
 
-   fcntl(sock, F_SETFL, O_NONBLOCK);
-   if (inet_addr(Host_Source.ip)!=-1)
-   {
+   Inet_SetNonBlock(sock);
+
+   if (inet_addr(Host_Source.ip)!=-1) {
       SpoofIP=inet_addr(Host_Source.ip);
       Inet_GetMACfromString(Host_Source.mac, SpoofMAC);
-   }
-   else
-   {
+   } else {
       SpoofIP=inet_addr(Host_Dest.ip);
       Inet_GetMACfromString(Host_Dest.mac, SpoofMAC);
    }
 
-   if (inet_addr(Host_Source.ip)!=-1 && inet_addr(Host_Dest.ip)!=-1)
-   {
+   if (inet_addr(Host_Source.ip)!=-1 && inet_addr(Host_Dest.ip)!=-1) {
        Hosts=calloc(1,sizeof(u_long));
        MACHosts=calloc(6,sizeof(char));
        Inet_GetMACfromString(Host_Dest.mac, MACHosts);
        Hosts[0]=inet_addr(Host_Dest.ip);
        hnumb=1;
-   }
-   else
-   {
+   } else {
        Hosts=calloc(number_of_hosts_in_lan-2,sizeof(u_long));
        MACHosts=calloc(6*(number_of_hosts_in_lan-2),sizeof(char));
        for (i=j=0; i<number_of_hosts_in_lan; i++)
@@ -129,15 +124,16 @@ int basilisk(void *dummy)
 
    ReceivedS=calloc(hnumb,sizeof(char));
    ReceivedD=calloc(hnumb,sizeof(char));
-
-   pck=Inet_Forge_packet(MTU);
-
+   
+   recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+      
    for (i=0; i<hnumb; i++)
    {
       char *to_send;
 
       usleep(1500);
-      to_send = pck;
+      to_send = recvpck.aligned;
       to_send += Inet_Forge_ethernet(to_send, MyMAC, SpoofMAC, ETH_P_IP);
       to_send += Inet_Forge_ip( to_send, Hosts[i], SpoofIP, ICMP_HEADER, 0xe77e, 0, IPPROTO_ICMP);
       icmp = (ICMP_header *) to_send;
@@ -146,10 +142,10 @@ int basilisk(void *dummy)
       icmp->un.echo.id = htons(0x570D);
       icmp->checksum = 0;
       icmp->checksum = Inet_Forge_ChecksumIP((u_short *)icmp, ICMP_HEADER);
-      Inet_SendRawPacket(sock, pck, ETH_HEADER + IP_HEADER + ICMP_HEADER );
+      Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + ICMP_HEADER );
 
       usleep(1500);
-      to_send = pck;
+      to_send = recvpck.aligned;
       to_send += Inet_Forge_ethernet(to_send, MyMAC, &MACHosts[i*6], ETH_P_IP);
       to_send += Inet_Forge_ip( to_send, SpoofIP, Hosts[i], ICMP_HEADER, 0xe77e, 0, IPPROTO_ICMP);
       icmp = (ICMP_header *) to_send;
@@ -158,19 +154,19 @@ int basilisk(void *dummy)
       icmp->un.echo.id = htons(0xD705);
       icmp->checksum = 0;
       icmp->checksum = Inet_Forge_ChecksumIP((u_short *)icmp, ICMP_HEADER);
-      Inet_SendRawPacket(sock, pck, ETH_HEADER + IP_HEADER + ICMP_HEADER );
+      Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + ICMP_HEADER );
    }
 
    TIME_START;
    do
    {
        short pkttype;
-       len = Inet_GetRawPacket(sock, pck, MTU, &pkttype);
+       len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
        TIME_FINISH;
 
        if ( len > 0 && pkttype == PACKET_HOST )
        {
-          eth = (ETH_header *) pck;
+          eth = (ETH_header *) recvpck.aligned;
           if (eth->type == htons(ETH_P_IP))
           {
              ip = (IP_header *)(eth+1);
@@ -228,7 +224,7 @@ int basilisk(void *dummy)
            Plugin_Output("\nPoisoning process successful!!!\n");
    }
 
-   Inet_Forge_packet_destroy( pck );
+   Inet_Forge_packet_destroy( recvpck.buf );
    free(Hosts);
    free(ReceivedS);
    free(ReceivedD);
