@@ -18,7 +18,6 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#include <fcntl.h>
 #include <unistd.h>
 
 #include "../../src/include/ec_main.h"
@@ -62,14 +61,17 @@ int Plugin_Fini(void *params)
 int beholder(void *dummy)
 {
    int MTU, sock;
-   char *recv_pck;
+   struct recv_packet recvpck;
 
    Plugin_Output("\nSupposed connections between... (press return to stop)\n\n");
 
    sock = Inet_OpenRawSock(Options.netiface);
    Inet_GetIfaceInfo(Options.netiface, &MTU, 0, 0, 0);
-   recv_pck = (char *)Inet_Forge_packet( MTU );
-   fcntl(sock,F_SETFL,O_NONBLOCK);
+   
+   recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+      
+   Inet_SetNonBlock(sock);
 
    loop
    {
@@ -78,14 +80,14 @@ int beholder(void *dummy)
       ARP_header *arp;
       ETH_header *eth;
 
-      len = Inet_GetRawPacket(sock, recv_pck, MTU, NULL);
+      len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, NULL);
 
       if (len>0)
       {
-         eth = (ETH_header *) recv_pck;
+         eth = (ETH_header *) recvpck.aligned;
          if ( ntohs(eth->type) == ETH_P_ARP )
          {
-            arp = (ARP_header *)(recv_pck + ETH_HEADER);
+            arp = (ARP_header *)(recvpck.aligned + ETH_HEADER);
             if ( ntohs(arp->opcode) == ARPOP_REQUEST )
             {
                struct in_addr addr_source;
@@ -107,7 +109,7 @@ int beholder(void *dummy)
 
       if (Plugin_Input(c, 1, P_NONBLOCK))
       {
-         Inet_Forge_packet_destroy( recv_pck );
+         Inet_Forge_packet_destroy( recvpck.buf );
          Inet_CloseRawSock(sock);
          return 0;
       }
