@@ -18,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: dummy.c,v 1.3 2001/09/27 19:07:40 alor Exp $
+    $Id: dummy.c,v 1.4 2002/02/22 19:48:56 alor Exp $
 */
 
 
@@ -40,7 +40,7 @@ char *dummy_message;
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops dummy_ops = {
    ettercap_version: VERSION,                            /* ettercap version MUST be the global VERSION */
    plug_info:        "Dummy plugin. It does nothing !",  /* a short description of the plugin (max 50 chars) */
    plug_version:     20,                                 /* the plugin version. note: 15 will be displayed as 1.5 */
@@ -65,7 +65,7 @@ int Plugin_Init(void *params)                            /* this function is cal
     *  the returned value MUST be the same as Plugin_Register()
     *  the opaque pointer params MUST be passed to Plugin_Register()
     */
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &dummy_ops);
 }
 
 int Plugin_Fini(void *params)                            /* this function is called on plugin unload */
