@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: golem.c,v 1.5 2002/02/10 10:07:01 alor Exp $
+    $Id: golem.c,v 1.6 2002/02/22 19:48:56 alor Exp $
 */
 
 #include <sys/types.h>
@@ -56,7 +56,7 @@ int Fake_Host(void);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops golem_ops = {
    ettercap_version: VERSION,
    plug_info:        "nice D.O.S.  BE CAREFUL !!",
    plug_version:     19,
@@ -69,7 +69,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &golem_ops);
 }
 
 int Plugin_Fini(void *params)
