@@ -17,11 +17,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: imp.c,v 1.5 2002/02/22 19:48:56 alor Exp $
+    $Id: imp.c,v 1.6 2002/05/07 22:04:14 alor Exp $
 */
 
 #include <unistd.h>
-#include <fcntl.h>
 #include <stdlib.h>
 #include <time.h>
 #include <sys/time.h>
@@ -82,21 +81,20 @@ int imp_function(void *dummy)
                  "\x43\x4B\x41\x41\x41\x41\x41\x41\x41\x41\x41\x41\x41"
                  "\x41\x41\x41\x41\x41\x41\x41\x41\x41\x41\x41\x41\x41"
                  "\x41\x41\x41\x41\x41\x41\x00\x00\x21\x00\x01";
-   char parser[4096], answers, *names, *buf;
+   char parser[4096], answers, *names;
+   struct recv_packet recvpck;
    char MyMAC[6], DestMAC[6], MyIP[16];
    ETH_header  *HEther;
    IP_header *HIP;
    UDP_header *HUDP;
    TIME_DECLARE;
 
-   if (!strcmp(Host_Dest.ip, ""))
-   {
+   if (!strcmp(Host_Dest.ip, "")) {
       Plugin_Output("\nNo destination host selected !!\n");
       return 0;
    }
 
-   if (!strcmp(Host_Dest.ip, Inet_MyIPAddress()))
-   {
+   if (!strcmp(Host_Dest.ip, Inet_MyIPAddress())) {
       Plugin_Output("\nThis plugin doesn't work on myself !!\n");
       return 0;
    }
@@ -108,38 +106,37 @@ int imp_function(void *dummy)
    Inet_GetMACfromString(Inet_MyMACAddress(), MyMAC);
    memcpy (DestMAC, Inet_MacFromIP(inet_addr(Host_Dest.ip)), 6);
    strncpy(MyIP,Inet_MyIPAddress(),16);
-
-   buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + UDP_HEADER + sizeof(dgram) );
-   Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_IP );
-   Inet_Forge_ip( buf + ETH_HEADER,
+   
+   recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+      
+   Inet_Forge_ethernet( recvpck.aligned, MyMAC, DestMAC, ETH_P_IP );
+   Inet_Forge_ip( recvpck.aligned + ETH_HEADER,
                   inet_addr(MyIP),
                   inet_addr(Host_Dest.ip),
                   UDP_HEADER + sizeof(dgram) - 1 ,
                   0xe77e, 0,
                   IPPROTO_UDP );
-   Inet_Forge_udp ( buf + ETH_HEADER + IP_HEADER,
+   Inet_Forge_udp ( recvpck.aligned + ETH_HEADER + IP_HEADER,
                     6969, 137,
                     dgram, sizeof(dgram) - 1);
-   memcpy( buf + ETH_HEADER + IP_HEADER + UDP_HEADER , dgram, sizeof(dgram));
-   Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + UDP_HEADER + sizeof(dgram) - 1);
-   Inet_Forge_packet_destroy( buf );
+   memcpy( recvpck.aligned + ETH_HEADER + IP_HEADER + UDP_HEADER , dgram, sizeof(dgram));
+   Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + UDP_HEADER + sizeof(dgram) - 1);
 
-   buf = Inet_Forge_packet( MTU );
-   fcntl(sock, F_SETFL, O_NONBLOCK);
+   Inet_SetNonBlock(sock);
 
    TIME_START;
 
-   do
-   {
+   do {
       short pkttype, len;
 
-      len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
+      len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
 
       TIME_FINISH;
 
       if (len > 0 && pkttype == PACKET_HOST)
       {
-         HEther = (ETH_header *) buf;
+         HEther = (ETH_header *) recvpck.aligned;
          if ( ntohs(HEther->type) == ETH_P_IP )
          {
             HIP = (IP_header *)(HEther + 1);
@@ -161,7 +158,7 @@ int imp_function(void *dummy)
    if (!reply)
    {
       Plugin_Output("\nNo replies within 3 seconds!!! (host could be down)\n");
-      Inet_Forge_packet_destroy(buf);
+      Inet_Forge_packet_destroy(recvpck.buf);
       return 0;
    }
 
@@ -170,7 +167,7 @@ int imp_function(void *dummy)
    if (!answers)
    {
       Plugin_Output("No name in the answer....\n");
-      Inet_Forge_packet_destroy(buf);
+      Inet_Forge_packet_destroy(recvpck.buf);
       return 0;
    }
 
@@ -197,7 +194,7 @@ int imp_function(void *dummy)
        tries++;
    }
 
-   Inet_Forge_packet_destroy(buf);
+   Inet_Forge_packet_destroy(recvpck.buf);
    free(names);
    return 0;
 }
