@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: leech.c,v 1.8 2002/03/16 10:24:44 alor Exp $
+    $Id: leech.c,v 1.9 2002/05/14 12:19:37 alor Exp $
 */
 
 #include <unistd.h>
@@ -78,18 +78,18 @@ int leech_function(void *dummy)
 
    Plugin_Output("Are you sure you want to isolate %s ? (yes/no) ", Host_Dest.ip );
    Plugin_Input(cont, 5, P_BLOCK);
-  
+
    if (strncmp(cont, "yes", 3))  // not sure... ;)
    {
       Plugin_Output("\nIt is safe!  for now...\n");
       return 0;
    }
-   
+
    if (number_of_hosts_in_lan <= 1) {
      Plugin_Output("\nBuilding host list for netmask %s, please wait...\n", Inet_MySubnet());
       number_of_hosts_in_lan = Inet_HostInLAN();
    }
-   
+
    for (i=0; i < number_of_hosts_in_lan; i++)
      if (!strcmp(Host_Dest.ip, Host_In_LAN[i].ip))
         Inet_GetMACfromString(Host_In_LAN[i].mac, MACD);
@@ -108,9 +108,9 @@ int leech_function(void *dummy)
    loop
    {
       int j;
-      
+
       i++;
-     
+
       for (j=0; j<number_of_hosts_in_lan; j++)
       {
          IPS = inet_addr(Host_In_LAN[j].ip);
@@ -125,22 +125,31 @@ int leech_function(void *dummy)
 
       if (Plugin_Input(cont, 1, P_NONBLOCK))
       {
+       	Plugin_Output("Do you want to reARP %s ? (yes/no) ", Host_Dest.ip );
+       	Plugin_Input(cont, 5, P_BLOCK);
+
+       	if (strncmp(cont, "yes", 3))  // not sure... ;)
+       	{
+        		Plugin_Output("\nOK, let's leave him blind...\n");
+        		return 0;
+       	}
+
          Plugin_Output("\nReARPing the victim (%s)...\n\n", Host_Dest.ip);
-              
+
          for (j=0; j<number_of_hosts_in_lan; j++)
          {
             IPS = inet_addr(Host_In_LAN[j].ip);
             Inet_GetMACfromString(Host_In_LAN[j].mac, MACA);
 
             Plugin_Output(" %s is at %s\n", Host_In_LAN[j].ip, Host_In_LAN[j].mac);
-            
+
             if (IPS != IPD)
             {
                Inet_Forge_arp( pck_to_send+ETH_HEADER, ARPOP_REPLY, MACA, IPS, MACD, IPD);
                Inet_SendRawPacket(sock, pck_to_send, ETH_HEADER + ARP_HEADER);
             }
          }
-         
+
          Inet_Forge_packet_destroy( pck_to_send );
          Inet_CloseRawSock(sock);
          return 0;
