@@ -17,12 +17,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ooze.c,v 1.4 2002/02/22 19:48:56 alor Exp $
+    $Id: ooze.c,v 1.5 2002/05/07 22:04:14 alor Exp $
 */
 
 
 #include <unistd.h>
-#include <fcntl.h>
 #include <stdlib.h>
 #include <time.h>
 #include <sys/time.h>
@@ -66,7 +65,7 @@ int Plugin_Fini(void *params)
 
 int ooze_function(void *dummy)
 {
-   char *buf;
+   struct recv_packet recvpck;
    int sock, MTU, i, reply=0;
    char MyMAC[6], DestMAC[6];
    char MyIP[16];
@@ -101,14 +100,15 @@ int ooze_function(void *dummy)
    memcpy (DestMAC, Inet_MacFromIP(inet_addr(Host_Dest.ip)), 6);
 
    strncpy(MyIP,Inet_MyIPAddress(),16);
-
-   buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
-
+   
+   recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+      
    for (i=0; i<num; i++)
    {
-         Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_IP );
+         Inet_Forge_ethernet( recvpck.aligned, MyMAC, DestMAC, ETH_P_IP );
 
-         Inet_Forge_ip( buf + ETH_HEADER,
+         Inet_Forge_ip( recvpck.aligned + ETH_HEADER,
                         inet_addr(MyIP),
                         inet_addr(Host_Dest.ip),
                         sizeof(ICMP_header),
@@ -116,22 +116,18 @@ int ooze_function(void *dummy)
                         0,
                         IPPROTO_ICMP );
 
-         Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+         Inet_Forge_icmp( recvpck.aligned + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
 
 
 
-         Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+         Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + ICMP_HEADER);
          usleep(1000);
    }
 
 
-   Inet_Forge_packet_destroy( buf );
-
    Plugin_Output("\n%d ICMP echo requests sent to %s. waiting for replies...\n\n", num, Host_Dest.ip);
 
-   buf = Inet_Forge_packet( MTU );
-
-   fcntl(sock, F_SETFL, O_NONBLOCK);
+   Inet_SetNonBlock(sock);
 
    TIME_START;
 
@@ -139,14 +135,14 @@ int ooze_function(void *dummy)
    {
       short pkttype, len;
 
-      len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
+      len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
 
       TIME_FINISH;
 
       if (len > 0 && pkttype == PACKET_HOST)
       {
 
-         HEther = (ETH_header *) buf;
+         HEther = (ETH_header *) recvpck.aligned;
          if ( ntohs(HEther->type) == ETH_P_IP )
          {
 
@@ -166,6 +162,8 @@ int ooze_function(void *dummy)
 
    Inet_CloseRawSock(sock);
 
+   Inet_Forge_packet_destroy(recvpck.buf);
+
    return 0;
 }
 
