@@ -18,11 +18,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: triton.c,v 1.5 2002/02/22 19:48:56 alor Exp $
+    $Id: triton.c,v 1.6 2002/05/09 20:53:35 alor Exp $
 */
 
 #include <stdlib.h>
-#include <fcntl.h>
 #include <unistd.h>
 #include <sys/time.h>
 
@@ -69,7 +68,8 @@ int triton_function(void *dummy)
 {
    int sock, MTU, len=0, i;
    char c[2] = "";
-   char *buf, *pck_to_send;
+   char *pck_to_send;
+   struct recv_packet recvpck;
    u_long MyIP, NetMask;
    ETH_header *eth;
    IP_header  *ip;
@@ -81,8 +81,10 @@ int triton_function(void *dummy)
    sock = Inet_OpenRawSock(Options.netiface);
    Inet_GetIfaceInfo(Options.netiface, &MTU, MyMAC, &MyIP, &NetMask);
 
-   buf = Inet_Forge_packet(MTU);
-   fcntl(sock, F_SETFL, O_NONBLOCK);
+   recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+      
+   Inet_SetNonBlock(sock);
 
    if (number_of_hosts_in_lan > 1)  // active scanning... host per host requst a non local ip.
    {
@@ -95,30 +97,30 @@ int triton_function(void *dummy)
 
          Inet_GetMACfromString(Host_In_LAN[i].mac, MAC);
 
-         pck_to_send = buf;
+         pck_to_send = recvpck.aligned;
          pck_to_send += Inet_Forge_ethernet( pck_to_send, MyMAC, MAC, ETH_P_IP );
          pck_to_send += Inet_Forge_ip( pck_to_send, MyIP, inet_addr(NON_LOCAL_IP), TCP_HEADER, 0xe77e, 0, IPPROTO_TCP);
          pck_to_send += Inet_Forge_tcp( pck_to_send, 0xe77e, 80, 0, 0, TH_SYN, 0, 0);
 
-         Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + TCP_HEADER );
+         Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + TCP_HEADER );
 
          TIME_START;
 
          do
          {
-            len = Inet_GetRawPacket(sock, buf, MTU, NULL);
+            len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, NULL);
             TIME_FINISH;
 
             if (Plugin_Input(c, 1, P_NONBLOCK))
             {
-               Inet_Forge_packet_destroy( buf );
+               Inet_Forge_packet_destroy( recvpck.buf );
                Inet_CloseRawSock(sock);
                return 0;
             }
 
             if (len > 0)
             {
-               eth = (ETH_header *) buf;
+               eth = (ETH_header *) recvpck.aligned;
                if (eth->type == htons(ETH_P_IP))
                {
                   ip = (IP_header *)(eth+1);
@@ -141,7 +143,7 @@ int triton_function(void *dummy)
                         else
                            Plugin_Output("\t Found !! this is the gateway (%s)\n\n", Host_In_LAN[i].mac);
 
-                        Inet_Forge_packet_destroy( buf );
+                        Inet_Forge_packet_destroy( recvpck.buf );
                         Inet_CloseRawSock(sock);
                         return 0;
                      }
@@ -154,7 +156,7 @@ int triton_function(void *dummy)
          } while(TIME_ELAPSED < 3);
          Plugin_Output("\t no replies within 3 sec !\n");
       }
-      Inet_Forge_packet_destroy( buf );
+      Inet_Forge_packet_destroy( recvpck.buf );
       Inet_CloseRawSock(sock);
       return 0;
    }
@@ -166,11 +168,11 @@ int triton_function(void *dummy)
 
       loop
       {
-         len = Inet_GetRawPacket(sock, buf, MTU, NULL);
+         len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, NULL);
 
          if (len > 0)
          {
-            eth = (ETH_header *) buf;
+            eth = (ETH_header *) recvpck.aligned;
             if (eth->type == htons(ETH_P_IP))
             {
                ip = (IP_header *)(eth+1);
@@ -190,7 +192,7 @@ int triton_function(void *dummy)
 
          if (Plugin_Input(c, 1, P_NONBLOCK))
          {
-            Inet_Forge_packet_destroy( buf );
+            Inet_Forge_packet_destroy( recvpck.buf );
             Inet_CloseRawSock(sock);
             return 0;
          }
