@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_linux.c,v 1.9 2002/04/07 22:37:31 alor Exp $
+    $Id: ec_inet_linux.c,v 1.12 2002/05/13 20:22:31 alor Exp $
 */
 
 #include "../../include/ec_main.h"
@@ -29,6 +29,7 @@
 #include <fcntl.h>
 
 #include "../../include/ec_thread.h"
+#include "../../include/ec_inet.h"
 #include "../../include/ec_inet_forge.h"
 #include "../../include/ec_inet_structures.h"
 
@@ -48,6 +49,7 @@ int Inet_OpenRawSock(char *iface);
 void Inet_CloseRawSock(int sock);
 int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
 int Inet_SendRawPacket(int sock, char *buffer, int len);
+void Inet_SetNonBlock(int sock);
 void Inet_Restore_ifr(void);
 void Inet_DisableForwarding(void);
 void Inet_RestoreForwarding(void);
@@ -282,6 +284,15 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
 }
 
 
+void Inet_SetNonBlock(int sock)
+{
+   DEBUG_MSG("Inet_SetNonBlock fd = %d", sock);
+
+   fcntl(sock, F_SETFL, O_NONBLOCK);
+
+}
+
+
 void Inet_CloseRawSock(int sock)
 {
 
@@ -487,11 +498,8 @@ void Inet_DisableForwarding(void)
    FILE *fd;
 
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "r");
-   if (fd < 0 )
-   {
-      DEBUG_MSG("fopen(/proc/sys/net/ipv4/ip_forward)");
-      return;
-   }
+   if (fd == NULL)
+      Error_msg("failed to open /proc/sys/net/ipv4/ip_forward");
 
    fscanf(fd, "%c", &IpForward_status);
    fclose(fd);
@@ -501,11 +509,8 @@ void Inet_DisableForwarding(void)
    atexit(Inet_RestoreForwarding);
 
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "w");
-   if (fd < 0 )
-   {
-      DEBUG_MSG("fopen(/proc/sys/net/ipv4/ip_forward)");
-      return;
-   }
+   if (fd == NULL)
+      Error_msg("failed to open /proc/sys/net/ipv4/ip_forward");
 
    fprintf(fd, "0");
    fclose(fd);
@@ -520,11 +525,8 @@ void Inet_RestoreForwarding(void)
    if (strcmp(ECThread_getname(pthread_self()), PROGRAM)) return;
 
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "w");
-   if (fd < 0 )
-   {
-      DEBUG_MSG("fopen(/proc/sys/net/ipv4/ip_forward)");
-      return;
-   }
+   if (fd == NULL)
+      Error_msg("failed to open /proc/sys/net/ipv4/ip_forward");
 
    DEBUG_MSG("Inet_RestoreForwarding to %c", IpForward_status);
 
@@ -552,7 +554,7 @@ char *Inet_MacFromIP(unsigned long ip)
 
    if (ioctl(sock_raw, SIOCGARP, (caddr_t)&ar) == -1)  // not in cache... try to find it...
    {
-      u_char *buf;
+      struct recv_packet recvpck;
       char MyMAC[6];
       u_long MyIP;
       int MTU, sock;
@@ -564,8 +566,7 @@ char *Inet_MacFromIP(unsigned long ip)
 
       Inet_GetIfaceInfo(Options.netiface, &MTU, MyMAC, &MyIP, NULL);
 
-      if (ip == MyIP)
-      {
+      if (ip == MyIP) {
          DEBUG_MSG("Inet_MacFromIP -- try to find me... ;)");
 
          memcpy(&ar.arp_ha.sa_data, MyMAC, ETHER_ADDR_LEN);
@@ -574,16 +575,18 @@ char *Inet_MacFromIP(unsigned long ip)
          return (char *) ar.arp_ha.sa_data;
       }
 
-      buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
-      Inet_Forge_ethernet( buf, MyMAC, ETH_BROADCAST, ETH_P_ARP );
+      recvpck.buf = Inet_Forge_packet( MTU + ALIGN_ETH_TO_WORD );
+      recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
 
-      Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
+      Inet_Forge_ethernet( recvpck.aligned, MyMAC, ETH_BROADCAST, ETH_P_ARP );
+
+      Inet_Forge_arp(recvpck.aligned + ETH_HEADER, ARPOP_REQUEST,
                          MyMAC, MyIP,
                          ARP_BROADCAST, ip );
 
-      Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
-      Inet_Forge_packet_destroy( buf );
-      buf = Inet_Forge_packet( MTU );
+      Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + ARP_HEADER);
+
+		memset(recvpck.aligned, 0, MTU);
 
       fcntl(sock, F_SETFL, O_NONBLOCK);
       TIME_START;
@@ -595,10 +598,10 @@ char *Inet_MacFromIP(unsigned long ip)
          ETH_header *ethpkt;
          ARP_header *arppkt;
 
-         len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
+         len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
 
-         ethpkt = (ETH_header *)buf;
-         arppkt = (ARP_header *)(buf + ETH_HEADER);
+         ethpkt = (ETH_header *)recvpck.aligned;
+         arppkt = (ARP_header *)(ethpkt + 1);
 
          TIME_FINISH;
 
@@ -607,7 +610,7 @@ char *Inet_MacFromIP(unsigned long ip)
             if ( *(unsigned long *)arppkt->source_ip == ip )
             {
                memcpy(&ar.arp_ha.sa_data, &arppkt->source_add, ETHER_ADDR_LEN);
-               Inet_Forge_packet_destroy( buf );
+               Inet_Forge_packet_destroy( recvpck.buf );
                Inet_CloseRawSock(sock);
                Inet_CloseRawSock(sock_raw);
                return (char *) ar.arp_ha.sa_data;
@@ -615,6 +618,7 @@ char *Inet_MacFromIP(unsigned long ip)
          }
       } while ( TIME_ELAPSED < 0.5 );
 
+		Inet_Forge_packet_destroy( recvpck.buf );
       Inet_CloseRawSock(sock);
       Inet_CloseRawSock(sock_raw);
       return ETH_BROADCAST;  // workaround for non local ip
