@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_decodedata.c,v 1.22 2002/04/11 20:16:36 alor Exp $
+    $Id: ec_decodedata.c,v 1.26 2002/06/03 07:20:57 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -69,6 +69,11 @@ SLIST_HEAD(, conn_hash_list) conn_hash_array[HASH_SIZE];
 pthread_mutex_t passive_mutex = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t connection_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+
+int conn_list_modified = 0;   /* use these flags to refresh the interfaces */
+int pass_list_modified = 0;
+
+
 #ifndef HAVE_CTYPE_H
    int isprint(int c);
 #endif
@@ -176,7 +181,7 @@ int Decodedata_MakeConnectionList(CONNECTION *data)
       }
 
       Decodedata_UpdateInfo(&Conn_Between_Hosts[index], data);
-
+      
       pthread_mutex_unlock(&connection_mutex);
 
       return number_of_connections;
@@ -189,6 +194,8 @@ int Decodedata_MakeConnectionList(CONNECTION *data)
       else
          number_of_connections++;
 
+      conn_list_modified = 1;
+      
       DEBUG_MSG("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", number_of_connections,
                    data->proto, data->source_ip, data->source_port, data->dest_ip, data->dest_port);
 
@@ -243,11 +250,13 @@ int Decodedata_MakeConnectionList(CONNECTION *data)
          if (strcmp(data->user, ""))
          {
             strtok(data->user, "\n");
+            if (data->user[0] == '\n') data->user[0] = '\0';   /* workaround for strtok */
             snprintf(Conn_Between_Hosts[number_of_connections-1].user, 30, "USER: %s", data->user);
          }
          if (strcmp(data->pass, ""))
          {
             strtok(data->pass, "\n");
+            if (data->pass[0] == '\n') data->pass[0] = '\0';   /* workaround for strtok */
             snprintf(Conn_Between_Hosts[number_of_connections-1].pass, 30, "PASS: %s", data->pass);
          }
          if (strcmp(data->info, "")) strlcpy(Conn_Between_Hosts[number_of_connections-1].info, data->info, 100);
@@ -267,18 +276,23 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 
    if (ptr->proto == 'T')
    {
-      if (data->flags & TH_RST)
+      if (data->flags & TH_RST) {
          sprintf(ptr->status,  "KILLED");
-      else if (data->flags & TH_SYN)
+         conn_list_modified = 1;
+      } else if (data->flags & TH_SYN) {
          sprintf(ptr->status,  "OPENING");
-      else if (data->flags & TH_FIN)
+         conn_list_modified = 1;
+      } else if (data->flags & TH_FIN) {
          sprintf(ptr->status,  "CLOSING");
-      else if (data->flags & TH_PSH)
+         conn_list_modified = 1;
+      } else if (data->flags & TH_PSH) {
          sprintf(ptr->status,  "ACTIVE");
-      else if (data->flags & TH_ACK)
-      {
-         if (!strcmp(ptr->status, "CLOSING"))   // FIN ACK
+         conn_list_modified = 1;
+      } else if (data->flags & TH_ACK) {
+         if (!strcmp(ptr->status, "CLOSING")) {   // FIN ACK
             sprintf(ptr->status,  "CLOSED");          // ACK
+            conn_list_modified = 1;
+         }
       }
       ptr->timestamp = time(NULL);
    }
@@ -299,6 +313,7 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 
             ptr->user[0] = ' ';
             strtok(ptr->user, "\n");
+            if (ptr->user[0] == '\n') ptr->user[0] = '\0';   /* workaround for strtok */
 
             if ( data->dest_port == 23 || data->source_port == 23 ||
                  data->dest_port == 513 || data->source_port == 513 )
@@ -306,6 +321,7 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 
             snprintf(str, sizeof(ptr->user), "USER:%s", ptr->user);
             strlcpy(ptr->user, str, sizeof(ptr->user));
+            conn_list_modified = 1;
          }
       }
       if ( ptr->user[0] != 0 && ptr->pass[0] == 0 )      // the string is under construction
@@ -318,17 +334,19 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 
             ptr->pass[0] = ' ';
             strtok(ptr->pass, "\n");
+            if (ptr->pass[0] == '\n') ptr->pass[0] = '\0';   /* workaround for strtok */
 
             snprintf(str, sizeof(ptr->pass), "PASS:%s", ptr->pass);
             strlcpy(ptr->pass, str,sizeof(ptr->pass));
+            conn_list_modified = 1;
          }
       }
 
-      if (strlen(data->info) && !strchr(ptr->info, '\n'))
+      if (strlen(data->info) && !strchr(ptr->info, '\n')) {
          strlcat(ptr->info, data->info, sizeof(ptr->info));
-   }
-   else
-   {
+         conn_list_modified = 1;
+      }
+   } else {
       if ( (data->flags & TH_SYN) ||
            ( data->dest_port != 23 && data->source_port != 23 &&
              data->dest_port != 513 && data->source_port != 513) )  // telnet and rlogin are enabled only on syn
@@ -347,8 +365,7 @@ void * DecodeData_Connection_Timeouter(void *dummy)      // Timeouter thread
    {
       pthread_testcancel();
 
-      if (number_of_connections <= 0)
-      {
+      if (number_of_connections <= 0) {
          usleep(5000);
          continue;
       }
@@ -357,16 +374,17 @@ void * DecodeData_Connection_Timeouter(void *dummy)      // Timeouter thread
 
       pthread_mutex_lock(&connection_mutex);
 
-      for (i = 0; i < number_of_connections; i++)
-      {
-         if (Conn_Between_Hosts[i].proto == 'T')
-         {
-            if (!strcmp(Conn_Between_Hosts[i].status, "ACTIVE") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_SILENT)
+      for (i = 0; i < number_of_connections; i++) {
+         if (Conn_Between_Hosts[i].proto == 'T') {
+            if (!strcmp(Conn_Between_Hosts[i].status, "ACTIVE") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_SILENT) {
                strcpy(Conn_Between_Hosts[i].status, "silent");
-
+               conn_list_modified = 1;
+            }
             if (strcmp(Conn_Between_Hosts[i].status, "KILLED") &&
-                strcmp(Conn_Between_Hosts[i].status, "CLOSED") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_TIMEOUT) // 10 min of timeout
+                strcmp(Conn_Between_Hosts[i].status, "CLOSED") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_TIMEOUT) { // 10 min of timeout
                strcpy(Conn_Between_Hosts[i].status, "timeout");
+               conn_list_modified = 1;
+            }
          }
       }
 
@@ -374,6 +392,8 @@ void * DecodeData_Connection_Timeouter(void *dummy)      // Timeouter thread
 
       sleep(2);
    }
+
+   return NULL;
 }
 
 
@@ -387,8 +407,7 @@ int Decodedata_RefreshConnectionList(void)
    pthread_mutex_trylock(&connection_mutex);
 
    for (i=0; i<HASH_SIZE; i++)
-      while(!SLIST_EMPTY(&conn_hash_array[i]))
-      {
+      while(!SLIST_EMPTY(&conn_hash_array[i])) {
          current = SLIST_FIRST(&conn_hash_array[i]);
          SLIST_REMOVE_HEAD(&conn_hash_array[i], next);
          free(current);
@@ -397,7 +416,8 @@ int Decodedata_RefreshConnectionList(void)
    if (Conn_Between_Hosts) free(Conn_Between_Hosts);
    Conn_Between_Hosts = NULL;
    number_of_connections = 0;
-
+   conn_list_modified = 1;
+   
    pthread_mutex_unlock(&connection_mutex);
 
    return 0;
@@ -410,32 +430,36 @@ void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data)
 
    char OS[60];
 
-   if (!strcmp(ptr->ip, ""))
+   if (!strcmp(ptr->ip, "")) {
       strlcpy(ptr->ip, data->ip, sizeof(ptr->ip));
+      pass_list_modified = 1;
+   }
 
-   if (!strcmp(ptr->mac, "") && strcmp(data->type, "NL"))   // no mac for non local hosts
+   if (!strcmp(ptr->mac, "") && strcmp(data->type, "NL")) {   // no mac for non local hosts
       strlcpy(ptr->mac, data->mac, sizeof(ptr->mac));
+      pass_list_modified = 1;
+   }
 
-   if (!strcmp(ptr->type, ""))
+   if (!strcmp(ptr->type, "")) {
       strlcpy(ptr->type, data->type, sizeof(ptr->type));
-
+      pass_list_modified = 1;
+   }
+   
    ptr->hop = data->hop;
 
-   if (strcmp(data->fingerprint, ""))
-   {
+   if (strcmp(data->fingerprint, "")) {
       if (!strcmp(ptr->fingerprint, ""))
          strlcpy(ptr->fingerprint, data->fingerprint, sizeof(ptr->fingerprint));
 
-      if (!strcmp(strrchr(ptr->fingerprint, ':'), ":A") || !strcmp(ptr->os, "") )
-      {
+      if (!strcmp(strrchr(ptr->fingerprint, ':'), ":A") || !strcmp(ptr->os, "") ) {
          strlcpy(ptr->fingerprint, data->fingerprint, sizeof(ptr->fingerprint));
 
          DEBUG_MSG("Decodedata_UpdatePassiveInfo -- %15s %25s", data->ip, data->fingerprint);
 
-         if (Decodedata_GetPassiveOS(data->fingerprint, OS) == 0)
+         if (Decodedata_GetPassiveOS(data->fingerprint, OS) == 0) {
             strlcpy(ptr->os, OS, sizeof(ptr->os));
-         else
-         {
+            pass_list_modified = 1;
+         } else {
             ptr->os[0] = 0;
             strlcpy(ptr->os + 1, OS, 58);
             ptr->os[sizeof(ptr->os)-1] = '\0';
@@ -455,51 +479,37 @@ void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data)
          if (LIST_EMPTY(&ptr->tcp_ports))
             LIST_INSERT_HEAD(&ptr->tcp_ports, newelem, next);
          else
-            LIST_FOREACH(current, &ptr->tcp_ports, next)
-            {
-               if (current->port == data->port)
-               {
+            LIST_FOREACH(current, &ptr->tcp_ports, next) {
+               if (current->port == data->port) {
                   strlcpy(current->banner, data->banner, sizeof(current->banner));
                   free(newelem);
                   break;
-               }
-               else if (current->port > data->port)
-               {
+               } else if (current->port > data->port) {
                   if (current == LIST_FIRST(&ptr->tcp_ports))
                      LIST_INSERT_HEAD(&ptr->tcp_ports, newelem, next);
                   else
                      LIST_INSERT_BEFORE(current, newelem, next);
                   break;
-               }
-               else if (LIST_NEXT(current, next) == LIST_END(&ptr->tcp_ports))
-               {
+               } else if (LIST_NEXT(current, next) == LIST_END(&ptr->tcp_ports)) {
                   LIST_INSERT_AFTER(current, newelem, next);
                   break;
                }
             }
-      }
-      else if (data->proto == 'U')
-      {
+      } else if (data->proto == 'U') {
          if (LIST_EMPTY(&ptr->udp_ports))
             LIST_INSERT_HEAD(&ptr->udp_ports, newelem, next);
          else
-            LIST_FOREACH(current, &ptr->udp_ports, next)
-            {
-               if (current->port == data->port)
-               {
+            LIST_FOREACH(current, &ptr->udp_ports, next) {
+               if (current->port == data->port) {
                   free(newelem);
                   break;
-               }
-               else if (current->port > data->port)
-               {
+               } else if (current->port > data->port) {
                   if (current == LIST_FIRST(&ptr->udp_ports))
                      LIST_INSERT_HEAD(&ptr->udp_ports, newelem, next);
                   else
                      LIST_INSERT_BEFORE(current, newelem, next);
                   break;
-               }
-               else if (LIST_NEXT(current, next) == LIST_END(&ptr->udp_ports))
-               {
+               } else if (LIST_NEXT(current, next) == LIST_END(&ptr->udp_ports)) {
                   LIST_INSERT_AFTER(current, newelem, next);
                   break;
                }
@@ -525,7 +535,7 @@ int Decodedata_MakePassiveList(PASSIVE_DATA *data)
       {
          num_conn++;
 
-         if (!strcmp(data->type, "NL") && !strcmp(ptr->mac, data->mac))      // the packet is from the GW...
+         if (!strcmp(data->type, "NL") && !strcmp(ptr->mac, data->mac) && !strcmp(ptr->type,""))      // the packet is from the GW...
          {                                                                 // search and mark it
             sprintf(ptr->type, "GW");
             strlcpy(ptr->gwforthis, data->ip, sizeof(ptr->gwforthis));
@@ -548,6 +558,8 @@ int Decodedata_MakePassiveList(PASSIVE_DATA *data)
    {
       int j;
       struct open_ports *cur;
+   
+      pass_list_modified = 1;
 
       DEBUG_MSG("Decodedata_MakePassiveList - new node ! %d ! %s - %s", num_conn, data->ip, data->fingerprint);
 
@@ -608,6 +620,8 @@ int Decodedata_FreePassiveList(void)
    Passive_Host = NULL;
    number_of_passive_hosts = 0;
 
+   pass_list_modified = 1;
+   
    pthread_mutex_unlock(&passive_mutex);
 
    return 0;
