@@ -17,14 +17,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_vnc.c,v 1.4 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_dissector_vnc.c,v 1.5 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 
 // protos
 
@@ -49,9 +48,7 @@ FUNC_DISSECTOR(Dissector_vnc)
 
    if ( (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == 0) && sscanf(payload, "RFB %03d.%03d\n", &major, &minor) )
    {
-      #ifdef DEBUG
-         Debug_msg("\tDissector_VNC %d %d", major, minor);
-      #endif
+      DEBUG_MSG("\tDissector_VNC %d %d", major, minor);
       Dissector_StateMachine_SetStatus(data_to_ettercap, 1, NULL);
       return 0;
    }
@@ -94,3 +91,6 @@ FUNC_DISSECTOR(Dissector_vnc)
 }
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
