@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_grell.c,v 1.13 2002/04/12 20:05:28 alor Exp $
+    $Id: ec_grell.c,v 1.16 2002/06/03 07:20:57 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -62,8 +62,41 @@ void Grell_fini(void *dummy);
 void * Grell_spawn(void *local_father_data);
 void * Grell_start(void *);
 pthread_t Grell_Run(void);
+int Grell_ToBeSniffed(SNIFFED_DATA *data);
 
 // ================================
+int Grell_ToBeSniffed(SNIFFED_DATA *data)
+{
+   char s=0, ps=0, d=0, pd=0;
+
+   if (current_illithid_data.proto != 'A')
+      if (current_illithid_data.proto != data->proto) return 0;
+
+   if (current_illithid_data.source_port == 0) ps = 1;
+   if (current_illithid_data.dest_port == 0) pd = 1;
+   if (current_illithid_data.source_ip == 0) s = 1;
+   if (current_illithid_data.dest_ip == 0) d = 1;
+
+   if (s || current_illithid_data.source_ip == data->fast_source_ip)
+      if (ps || current_illithid_data.source_port == data->source_port)
+      {  s = 1;   ps = 1;  }
+
+   if (s || current_illithid_data.source_ip == data->fast_dest_ip)
+      if (ps || current_illithid_data.source_port == data->dest_port)
+      {  s = 1;   ps = 1;  }
+
+   if (d || current_illithid_data.dest_ip == data->fast_source_ip)
+      if (pd || current_illithid_data.dest_port == data->source_port)
+      {  d = 1;   pd = 1;  }
+
+   if (d || current_illithid_data.dest_ip == data->fast_dest_ip)
+      if (pd || current_illithid_data.dest_port == data->dest_port)
+      {  d = 1;   pd = 1;  }
+
+   return ( Options.reverse ^ (s && ps && d && pd) );
+}
+
+
 
 void Grell_Dissector(char *payload, CONNECTION *data_to_ettercap)
 {
@@ -100,6 +133,9 @@ static void client_parse(char *buf, int len, public_data *son_data)
    strncpy(data_to_ettercap.dest_ip, inet_ntoa(dest), sizeof(data_to_ettercap.dest_ip)-1);
    data_to_ettercap.dest_ip[sizeof(data_to_ettercap.dest_ip)-1]='\0';
 
+   data_to_ettercap.fast_source_ip = ntohl(son_data->client_sin.sin_addr.s_addr);
+   data_to_ettercap.fast_dest_ip = ntohl(dest.s_addr);
+
    data_to_ettercap.source_port = ntohs(son_data->client_sin.sin_port);
    data_to_ettercap.dest_port = ntohs(son_data->ServerPort);
    data_to_ettercap.source_seq = 0;
@@ -118,6 +154,9 @@ static void client_parse(char *buf, int len, public_data *son_data)
       strncpy(sniff_data_to_ettercap.dest_ip, inet_ntoa(dest), sizeof(sniff_data_to_ettercap.dest_ip)-1);
       sniff_data_to_ettercap.dest_ip[sizeof(sniff_data_to_ettercap.dest_ip)-1]='\0';
 
+      sniff_data_to_ettercap.fast_source_ip = ntohl(son_data->client_sin.sin_addr.s_addr);
+      sniff_data_to_ettercap.fast_dest_ip = ntohl(dest.s_addr);
+
       sniff_data_to_ettercap.source_port = ntohs(son_data->client_sin.sin_port);
       sniff_data_to_ettercap.dest_port = ntohs(son_data->ServerPort);
       sniff_data_to_ettercap.seq = 0;
@@ -129,7 +168,8 @@ static void client_parse(char *buf, int len, public_data *son_data)
       memset(&sniff_data_to_ettercap.data, 0, sizeof(sniff_data_to_ettercap.data));
       memcpy(&sniff_data_to_ettercap.data, buf, len);
 
-      Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
+      if (Grell_ToBeSniffed(&sniff_data_to_ettercap))
+         Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
    }
 }
 
@@ -149,6 +189,9 @@ static void server_parse(char *buf, int len, public_data *son_data)
    strncpy(data_to_ettercap.dest_ip, inet_ntoa(son_data->client_sin.sin_addr), sizeof(data_to_ettercap.dest_ip)-1);
    data_to_ettercap.dest_ip[sizeof(data_to_ettercap.dest_ip)-1]='\0';
 
+   data_to_ettercap.fast_source_ip = ntohl(source.s_addr);
+   data_to_ettercap.fast_dest_ip = ntohl(son_data->client_sin.sin_addr.s_addr);
+
    data_to_ettercap.source_port = ntohs(son_data->ServerPort);
    data_to_ettercap.dest_port = ntohs(son_data->client_sin.sin_port);
    data_to_ettercap.source_seq = 0;
@@ -166,6 +209,9 @@ static void server_parse(char *buf, int len, public_data *son_data)
       strncpy(sniff_data_to_ettercap.dest_ip, inet_ntoa(son_data->client_sin.sin_addr), sizeof(sniff_data_to_ettercap.dest_ip)-1);
       sniff_data_to_ettercap.dest_ip[sizeof(sniff_data_to_ettercap.dest_ip)-1]='\0';
 
+      sniff_data_to_ettercap.fast_source_ip = ntohl(source.s_addr);
+      sniff_data_to_ettercap.fast_dest_ip = ntohl(son_data->client_sin.sin_addr.s_addr);
+
       sniff_data_to_ettercap.source_port = ntohs(son_data->ServerPort);
       sniff_data_to_ettercap.dest_port = ntohs(son_data->client_sin.sin_port);
       sniff_data_to_ettercap.seq = 0;
@@ -177,7 +223,8 @@ static void server_parse(char *buf, int len, public_data *son_data)
       memset(&sniff_data_to_ettercap.data, 0, sizeof(sniff_data_to_ettercap.data));
       memcpy(&sniff_data_to_ettercap.data, buf, len);
 
-      Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
+      if (Grell_ToBeSniffed(&sniff_data_to_ettercap))
+         Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
    }
 }
 
@@ -348,7 +395,7 @@ static int server_init(char *buf, size_t size, public_data *son_data)
                return -1;    // if it can't handle proxy auth...
             }
             found = strstr(buf, "200");
-           if ( found && (unsigned int)(found-buf) < 20 ) break;
+            if ( found && (unsigned int)(found-buf) < 20 ) break;
          }
       }
 
@@ -502,22 +549,24 @@ void * Grell_spawn(void *local_father_data)
       poll(poll_fd,2,-1);
 
       //if (FD_ISSET(son_data.client_fd, &fds))
-      if (poll_fd[0].revents & POLLIN)
+      if (poll_fd[0].revents & (POLLIN | POLLHUP | POLLERR | POLLNVAL))
       {
          i = sizeof(buf);
          if ((i = client_read(buf, i-2, &son_data)) <= 0) break;
          buf[i]=0;
          if (server_write(buf, i, &son_data) != i)   break;
          client_parse(buf, i, &son_data);
+         if (poll_fd[0].revents & (POLLHUP | POLLERR | POLLNVAL)) break;
       }
       else //if (FD_ISSET(son_data.server_fd, &fds))
-      if (poll_fd[1].revents & POLLIN)
+      if (poll_fd[1].revents & (POLLIN | POLLHUP | POLLERR | POLLNVAL))
       {
          i = sizeof(buf);
          if ((i = server_read(buf, i-2, &son_data)) <= 0) break;
          buf[i]=0;
          if (client_write(buf, i, &son_data) != i) break;
          server_parse(buf, i, &son_data);
+         if (poll_fd[1].revents & (POLLHUP | POLLERR | POLLNVAL)) break;
       }
    }
    server_close(&son_data);
@@ -603,6 +652,7 @@ void * Grell_start(void *none)
 
    exit_func_end();
 
+   return NULL;
 }
 
 pthread_t Grell_Run(void)
