@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet.c,v 1.29 2002/04/11 20:16:36 alor Exp $
+    $Id: ec_inet.c,v 1.34 2002/05/10 20:09:15 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -34,13 +34,13 @@
 	#include <Iphlpapi.h>
 #endif
 
-#include <fcntl.h>
 #include <signal.h>
 
 #ifndef WAIT_ANY
    #define WAIT_ANY       (-1)    /* Any process.  */
 #endif
 
+#include "include/ec_inet.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_buffer.h"
@@ -53,18 +53,12 @@ typedef struct {
 } host_list;
 
 
-#ifdef CYGWIN
-typedef struct sh {
-   SOCKET fd;
-   struct sockaddr_in sin;
-} socket_handle;
-#else
-typedef int socket_handle;
-#endif
-
 static char ETH_BROADCAST[6] = {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
 static char ARP_BROADCAST[6] = {0x0,0x0,0x0,0x0,0x0,0x0};
 
+char **Host_List;          // scan only these hosts
+int host_to_be_scanned;
+
 // protos...
 
 char * Inet_HostName(char *ip);
@@ -76,6 +70,7 @@ char * Inet_MySubnet(void);
 int Inet_HostInLAN(void);
 void Inet_Free_list(host_list *head);
 host_list *Inet_Host_in_LAN_list(char *iface);
+void Inet_Host_in_LAN_list_broadping(host_list *head, int sock, int MTU, u_int32 NetMask);
 SniffingHost *Inet_NoSniff(void);
 void Inet_PutMACinString(char *mac_string, unsigned char *MAC);
 int Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
@@ -101,6 +96,7 @@ int Inet_OpenRawSock(char *iface);
 void Inet_CloseRawSock(int sock);
 int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
 int Inet_SendRawPacket(int sock, char *buffer, int len);
+void Inet_SetNonBlock(int sock);
 void Inet_Restore_ifr(void);
 void Inet_DisableForwarding(void);
 void Inet_RestoreForwarding(void);
@@ -111,6 +107,9 @@ char *Inet_MacFromIP(unsigned long ip);
    void Inet_UnsetRoute(void);
    void Inet_SetRoute(void);
 #endif
+#ifdef CYGWIN
+HRESULT SendARP_(unsigned long DIP, unsigned long SIP, PULONG pMAC, PULONG ulen);
+#endif
 
 // ----------------------------------------
 
@@ -384,12 +383,91 @@ void Inet_Free_list(host_list *head)
 
 
 
+void Inet_Host_in_LAN_list_broadping(host_list *head, int sock, int MTU, u_int32 NetMask)
+{  
+   u_int32 BroadAdd;
+   struct recv_packet recvpck;
+   TIME_DECLARE;
+   
+   BroadAdd = head->IP_Add | (~NetMask);
+   
+   if (!Host_In_LAN)
+      fprintf(stdout, "Sending broadcast ping to %s...\n", int_ntoa(BroadAdd));
+   
+   
+   DEBUG_MSG("Inet_Host_in_LAN_list_broadping -- broad ping sent to %s", int_ntoa(BroadAdd));
+   
+   recvpck.buf = Inet_Forge_packet( ALIGN_ETH_TO_WORD + MTU);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+      
+   Inet_Forge_ethernet( recvpck.aligned, head->MAC_Add, ETH_BROADCAST, ETH_P_IP );
+   
+   Inet_Forge_ip( recvpck.aligned + ETH_HEADER,
+                  head->IP_Add,
+                  BroadAdd,
+                  sizeof(ICMP_header),
+                  0xe77e,
+                  0,
+                  IPPROTO_ICMP );
+   
+   Inet_Forge_icmp( recvpck.aligned + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+   Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+
+   DEBUG_MSG("Inet_Host_in_LAN_list_broadping -- listening for replies...");
+
+   Inet_SetNonBlock(sock);
+
+   TIME_START;
+      
+   do {
+      short pkttype;
+      int len;
+      host_list **current;
+      ETH_header *HEther;
+      IP_header *HIP;
+
+      TIME_FINISH;
+
+      len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
+
+      if (len > 0 && pkttype == PACKET_HOST) {
+         HEther = (ETH_header *) recvpck.aligned;
+         if ( ntohs(HEther->type) == ETH_P_IP ) {
+            HIP = (IP_header *)(HEther + 1);
+            if (HIP->proto != IPPROTO_ICMP) continue;
+            current = &head;
+
+            DEBUG_MSG("Inet_Host_in_LAN_list_broadping -- got a reply after %.5f seconds", TIME_ELAPSED );
+
+            number_of_hosts_in_lan++;
+
+            while(*current != NULL && memcmp(&((*current)->IP_Add),&HIP->source_ip,4))
+               current = (host_list **)&((*current)->next);
+
+            if (*current == NULL) {
+               if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
+                   ERROR_MSG("malloc()");
+               (*current)->next = NULL;
+               memcpy((*current)->MAC_Add, HEther->source_mac, 6);
+               memcpy((char *)&((*current)->IP_Add), &HIP->source_ip, 4);
+            }
+         }
+      }
+   } while ( TIME_ELAPSED < 2 );
+   
+   DEBUG_MSG("Inet_Host_in_LAN_list_broadping -- timeout after %.5f seconds", TIME_ELAPSED);
+   
+   Inet_Forge_packet_destroy( recvpck.buf );
+}
+
+
+
 host_list *Inet_Host_in_LAN_list(char *iface)
 {
    int sock, N_hosts, i, MTU;
-   u_long NetMask, BroadAdd, IP_to_use;
+   u_long NetMask, IP_to_use;
    host_list *head;
-   u_char *buf;
+   struct recv_packet recvpck;
    TIME_DECLARE;
 
    DEBUG_MSG("Inet_HostInLAN_list");
@@ -402,47 +480,24 @@ host_list *Inet_Host_in_LAN_list(char *iface)
 
    head->next = NULL;
 
-   sock = Inet_OpenRawSock(iface);
-
    Inet_GetIfaceInfo(iface, &MTU, head->MAC_Add, &head->IP_Add, &NetMask);
 
-   if (Options.silent)
-   {
-      Inet_CloseRawSock(sock);
+   if (Options.silent) {
       return head;
    }
-
+   
    N_hosts = ntohl(~NetMask);
 
    DEBUG_MSG("Inet_HostInLAN_list -- netmask 0x%0x  hosts %d", htonl(NetMask), N_hosts);
 
-   if (Options.broadping)
-   {
+   sock = Inet_OpenRawSock(iface);
+   
+   if (Options.broadping) {
 
-      BroadAdd = head->IP_Add | (~NetMask);
+      Inet_Host_in_LAN_list_broadping(head, sock, MTU, NetMask);
+      return head;
 
-      if (!Host_In_LAN)
-         fprintf(stdout, "Sending broadcast ping to %s...\n", int_ntoa(BroadAdd));
-
-
-      buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
-      Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_IP );
-
-      Inet_Forge_ip( buf + ETH_HEADER,
-                     head->IP_Add,
-                     BroadAdd,
-                     sizeof(ICMP_header),
-                     0xe77e,
-                     0,
-                     IPPROTO_ICMP );
-
-      Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
-      Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
-      Inet_Forge_packet_destroy( buf );
-
-   }
-   else // !broadping
-   {
+   } else {
 
       if (!Host_In_LAN && Options.spoofIp)
          fprintf(stdout, "Spoofing source IP with %s...\n", int_ntoa(Options.spoofIp));
@@ -452,12 +507,6 @@ host_list *Inet_Host_in_LAN_list(char *iface)
 
       if (!Host_In_LAN && host_to_be_scanned == 0) {
          fprintf(stdout, "\nSending %d ARP request...\n\n", N_hosts);
-#ifdef CYGWIN
-         fprintf(stdout, "* This process is terribly SLOW under Windows...\n");
-         fprintf(stdout, "* It takes a second for each ARP request.\n*\n");
-         fprintf(stdout, "* You are encouraged to save the host list to a file with the -k option\n");
-         fprintf(stdout, "* and load it (with -j <filename>) in the future to skip this scan.\n\n\n");
-#endif
       }
       else if (!Host_In_LAN && host_to_be_scanned > 0)
          fprintf(stdout, "\nSending %d ARP request...\n\n", host_to_be_scanned);
@@ -476,8 +525,7 @@ host_list *Inet_Host_in_LAN_list(char *iface)
 
          if (host_to_be_scanned > 0)   // only the hosts in the list
          {
-            for (i=0; i<host_to_be_scanned; i++)
-            {
+            for (i=0; i<host_to_be_scanned; i++) {
                host_list **current;
 
                dest_ip = inet_addr(Host_List[i]);
@@ -487,15 +535,14 @@ host_list *Inet_Host_in_LAN_list(char *iface)
                memset (mac, 0xff, sizeof(mac));
                ulLen = 6;
 
-               hr = SendARP (dest_ip, IP_to_use, (ULONG *)mac, &ulLen);
+               hr = SendARP_ (dest_ip, IP_to_use, (ULONG *)mac, &ulLen);
                Parser_StatusBar(host_to_be_scanned);
 
                if (hr != 0) continue;
 
 					if (dest_ip == head->IP_Add) continue; // skip our host
 
-               if (memcmp(mac, ARP_BROADCAST, 6))
-               {
+               if (memcmp(mac, ARP_BROADCAST, 6)) {
                   current = &head;
 
                   DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
@@ -505,8 +552,7 @@ host_list *Inet_Host_in_LAN_list(char *iface)
                   while(*current != NULL && memcmp(&((*current)->IP_Add), &dest_ip, 4))
                      current = (host_list **)&((*current)->next);
 
-                  if (*current == NULL)
-                  {
+                  if (*current == NULL) {
                      if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
                         ERROR_MSG("malloc()");
                      (*current)->next = NULL;
@@ -534,7 +580,7 @@ host_list *Inet_Host_in_LAN_list(char *iface)
                   memset (mac, 0xff, sizeof(mac));
                   ulLen = 6;
 
-                  hr = SendARP (dest_ip, IP_to_use, (ULONG *)mac, &ulLen);
+                  hr = SendARP_ (dest_ip, IP_to_use, (ULONG *)mac, &ulLen);
 
                   if (hr != 0) continue;
 
@@ -566,10 +612,10 @@ host_list *Inet_Host_in_LAN_list(char *iface)
 
       if (!fork())
       {
-         buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
+         recvpck.buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
 
          // frame ethernet header
-         Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_ARP );
+         Inet_Forge_ethernet( recvpck.buf, head->MAC_Add, ETH_BROADCAST, ETH_P_ARP );
 
          if (Options.spoofIp)
             IP_to_use = Options.spoofIp;
@@ -581,17 +627,19 @@ host_list *Inet_Host_in_LAN_list(char *iface)
             for (i=0; i<host_to_be_scanned; i++)
             {
                int dest_ip;
+               DEBUG_MSG("INET -- %s", Host_List[i]);
                dest_ip = inet_addr(Host_List[i]);
 
+               Parser_StatusBar(host_to_be_scanned);
+
                if (dest_ip == head->IP_Add) continue; // skip our host
 
-               Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
+               Inet_Forge_arp( recvpck.buf+ETH_HEADER, ARPOP_REQUEST,
                                   head->MAC_Add, IP_to_use,
                                   ARP_BROADCAST, dest_ip );
 
                usleep(Options.storm_delay);
-               Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
-               Parser_StatusBar(host_to_be_scanned);
+               Inet_SendRawPacket(sock, recvpck.buf, ETH_HEADER + ARP_HEADER);
             }
          }
          else  // all host in the subnet
@@ -605,19 +653,19 @@ host_list *Inet_Host_in_LAN_list(char *iface)
                if (dest_ip != head->IP_Add)
                {
                   // arp request
-                  Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
+                  Inet_Forge_arp( recvpck.buf+ETH_HEADER, ARPOP_REQUEST,
                                   head->MAC_Add, IP_to_use,
                                   ARP_BROADCAST, dest_ip );
 
                   usleep(Options.storm_delay);
-                  Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
+                  Inet_SendRawPacket(sock, recvpck.buf, ETH_HEADER + ARP_HEADER);
                }
 
                Parser_StatusBar(N_hosts);
             }
          }
 
-         Inet_Forge_packet_destroy( buf );
+         Inet_Forge_packet_destroy( recvpck.buf );
          usleep(500000);   // 0.5 second to wait for slower replies (ettercap is syncronized on this process)
          exit(0);          // the forked process must exit after arp storm
       }
@@ -628,109 +676,59 @@ host_list *Inet_Host_in_LAN_list(char *iface)
 
    DEBUG_MSG("Inet_HostInLAN_list -- listening for replies...");
 
-//   if (!Host_In_LAN)
-//      fprintf(stdout, "Listening for replies...\n");
-
-
-   fcntl(sock, F_SETFL, O_NONBLOCK);
-
+   Inet_SetNonBlock(sock);
+   
    TIME_START;
-
-   buf = Inet_Forge_packet( MTU );
-
-   if (Options.broadping)
-   {
-         do
-         {
-            short pkttype;
-            int len;
-            host_list **current;
-            ETH_header *HEther;
-            IP_header *HIP;
-
-            TIME_FINISH;
-
-            len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
-
-            if (len > 0 && pkttype == PACKET_HOST)
-            {
-               HEther = (ETH_header *) buf;
-               if ( ntohs(HEther->type) == ETH_P_IP )
-               {
-                  HIP = (IP_header *)(HEther + 1);
-                  if (HIP->proto != IPPROTO_ICMP) continue;
-                  current = &head;
-
-                  DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
-
-                  number_of_hosts_in_lan++;
-
-                  while(*current != NULL && memcmp(&((*current)->IP_Add),&HIP->source_ip,4))
-                     current = (host_list **)&((*current)->next);
-
-                  if (*current == NULL)
-                  {
-                     if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
-                         ERROR_MSG("malloc()");
-                     (*current)->next = NULL;
-                     memcpy((*current)->MAC_Add, HEther->source_mac, 6);
-                     memcpy((char *)&((*current)->IP_Add), &HIP->source_ip, 4);
-                  }
-               }
-            }
-         } while ( TIME_ELAPSED < 2 );
-
-   }
-   else  // !broadping
-   {
+   
+   recvpck.buf = Inet_Forge_packet( ALIGN_ETH_TO_WORD + MTU);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+              
 #ifndef CYGWIN
 
-         do
+   do
+   {
+      int leng = 0;
+      short pkttype;
+      host_list **current;
+      ETH_header *ethpkt;
+      ARP_header *arppkt;
+
+      leng = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
+
+      ethpkt = (ETH_header *)recvpck.aligned;
+      arppkt = (ARP_header *)(recvpck.aligned + ETH_HEADER);
+
+      TIME_FINISH;
+
+      if (leng > 0 && pkttype == PACKET_HOST && ethpkt->type == htons(ETH_P_ARP) && arppkt->opcode == htons(ARPOP_REPLY))
+      {
+         current = &head;
+
+         DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+
+         number_of_hosts_in_lan++;
+
+         while(*current != NULL && memcmp(&((*current)->IP_Add),arppkt->source_ip,4))
+            current = (host_list **)&((*current)->next);
+
+         if (*current == NULL)
          {
-            int leng = 0;
-            short pkttype;
-            host_list **current;
-            ETH_header *ethpkt;
-            ARP_header *arppkt;
-
-            leng = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
-
-            ethpkt = (ETH_header *)buf;
-            arppkt = (ARP_header *)(buf + ETH_HEADER);
-
-            TIME_FINISH;
-
-            if (leng > 0 && pkttype == PACKET_HOST && ethpkt->type == htons(ETH_P_ARP) && arppkt->opcode == htons(ARPOP_REPLY))
-            {
-               current = &head;
-
-               DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
-
-               number_of_hosts_in_lan++;
-
-               while(*current != NULL && memcmp(&((*current)->IP_Add),arppkt->source_ip,4))
-                  current = (host_list **)&((*current)->next);
-
-               if (*current == NULL)
-               {
-                  if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
-                     ERROR_MSG("malloc()");
-                  (*current)->next = NULL;
-                  memcpy((*current)->MAC_Add, arppkt->source_add, 6);
-                  memcpy((char *)&((*current)->IP_Add), arppkt->source_ip, 4);
-               }
-            }
-         } while ( waitpid(WAIT_ANY, NULL, WNOHANG) == 0 );
+            if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
+               ERROR_MSG("malloc()");
+            (*current)->next = NULL;
+            memcpy((*current)->MAC_Add, arppkt->source_add, 6);
+            memcpy((char *)&((*current)->IP_Add), arppkt->source_ip, 4);
+         }
+      }
+   } while ( waitpid(WAIT_ANY, NULL, WNOHANG) == 0 );
 
 #endif
 
-   }
-
 #ifndef CYGWIN
    DEBUG_MSG("Inet_HostInLAN_list -- waiting timed out after %.5f seconds", TIME_ELAPSED );
 #endif
 
-   Inet_Forge_packet_destroy( buf );
+   Inet_Forge_packet_destroy( recvpck.buf );
    Inet_CloseRawSock(sock);
    return head;
 }
@@ -742,7 +740,7 @@ SniffingHost *Inet_NoSniff(void)
    int i, j, len, sock, MTU, SniffTableIndex=0;
    ETH_header  *HEther;
    IP_header *HIP;
-   u_char *buf;
+   struct recv_packet recvpck;
    TIME_DECLARE;
 
    DEBUG_MSG("Inet_NoSniff");
@@ -756,7 +754,7 @@ SniffingHost *Inet_NoSniff(void)
 
    Inet_GetIfaceInfo(Options.netiface, &MTU, NULL, NULL, NULL);
 
-   buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
+   recvpck.buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
 
    for (i=0; i<number_of_hosts_in_lan; i++)
    {
@@ -768,9 +766,9 @@ SniffingHost *Inet_NoSniff(void)
          Inet_GetMACfromString(Host_In_LAN[0].mac, MyMAC);
          Inet_GetMACfromString(Host_In_LAN[i].mac, DestMAC);
 
-         Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_IP );
+         Inet_Forge_ethernet( recvpck.buf, MyMAC, DestMAC, ETH_P_IP );
 
-         Inet_Forge_ip( buf + ETH_HEADER,
+         Inet_Forge_ip( recvpck.buf + ETH_HEADER,
                         inet_addr(Host_In_LAN[0].ip),
                         inet_addr(Host_In_LAN[i].ip),
                         sizeof(ICMP_header),
@@ -778,20 +776,21 @@ SniffingHost *Inet_NoSniff(void)
                         0,
                         IPPROTO_ICMP );
 
-         Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+         Inet_Forge_icmp( recvpck.buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
 
-         Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+         Inet_SendRawPacket(sock, recvpck.buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
          usleep(1000);
       }
    }
 
-   Inet_Forge_packet_destroy( buf );
+   Inet_Forge_packet_destroy( recvpck.buf );
 
    DEBUG_MSG("Inet_NoSniff -- after ICMP storm");
 
-   buf = Inet_Forge_packet( MTU );
+   recvpck.buf = Inet_Forge_packet( ALIGN_ETH_TO_WORD + MTU);
+   recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
 
-   fcntl(sock, F_SETFL, O_NONBLOCK);
+   Inet_SetNonBlock(sock);
 
    TIME_START;
 
@@ -802,11 +801,11 @@ SniffingHost *Inet_NoSniff(void)
 
       TIME_FINISH;
 
-      len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
+      len = Inet_GetRawPacket(sock, recvpck.aligned, MTU, &pkttype);
 
       if (len > 0 && pkttype == PACKET_HOST)
       {
-         HEther = (ETH_header *) buf;
+         HEther = (ETH_header *) recvpck.aligned;
          if ( ntohs(HEther->type) == ETH_P_IP )
          {
             unsigned char MACS[20];
@@ -858,7 +857,7 @@ SniffingHost *Inet_NoSniff(void)
 
    DEBUG_MSG("Inet_NoSniff -- freeing buffer" );
 
-   Inet_Forge_packet_destroy( buf );
+   Inet_Forge_packet_destroy( recvpck.buf );
 
    Inet_CloseRawSock(sock);
    return (SniffTable);
@@ -907,35 +906,37 @@ int Inet_CheckSwitch()
    {
        int fakeip,destip,sock,MTU,i;
        char MyMAC[6],DestMAC[6];
-       char *buf;
+       struct recv_packet recvpck;
        TIME_DECLARE;
 
        fakeip=Inet_Fake_Host();
        destip=inet_addr(Host_In_LAN[1].ip);
        Inet_GetMACfromString(Host_In_LAN[1].mac, DestMAC);
        sock = Inet_OpenRawSock(Options.netiface);
-       fcntl(sock, F_SETFL, O_NONBLOCK);
+       Inet_SetNonBlock(sock);
        Inet_GetIfaceInfo(Options.netiface, &MTU, MyMAC, NULL, NULL);
        Inet_SetPromisc(Options.netiface);
 
-       buf = Inet_Forge_packet(MTU);
-       Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_IP );
-       Inet_Forge_ip( buf + ETH_HEADER,
+       recvpck.buf = Inet_Forge_packet( ALIGN_ETH_TO_WORD + MTU);
+       recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+       
+       Inet_Forge_ethernet( recvpck.aligned, MyMAC, DestMAC, ETH_P_IP );
+       Inet_Forge_ip( recvpck.aligned + ETH_HEADER,
                       fakeip, destip,
                       sizeof(ICMP_header),
                       0xe77e, 0,
                       IPPROTO_ICMP );
-       Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
-       Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+       Inet_Forge_icmp( recvpck.aligned + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+       Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + ICMP_HEADER);
 
-       Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_ARP );
-       Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REPLY,
+       Inet_Forge_ethernet( recvpck.aligned, MyMAC, DestMAC, ETH_P_ARP );
+       Inet_Forge_arp( recvpck.aligned+ETH_HEADER, ARPOP_REPLY,
                        DestMAC, fakeip,
                        DestMAC, destip );
        for(i=0; i<5; i++)
        {
            usleep(1000);
-           Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
+           Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + ARP_HEADER);
        }
 
        TIME_START;
@@ -943,13 +944,13 @@ int Inet_CheckSwitch()
        {
            short type; int len;
 
-           len=Inet_GetRawPacket(sock,buf,MTU,&type);
+           len=Inet_GetRawPacket(sock, recvpck.aligned, MTU, &type);
            TIME_FINISH;
 
             if (len>0)
             {
                ETH_header *eth;
-               eth=(ETH_header *)buf;
+               eth=(ETH_header *)recvpck.aligned;
                if (!memcmp(DestMAC,eth->dest_mac,6))
                {
                   link_type=1;
@@ -958,7 +959,7 @@ int Inet_CheckSwitch()
             }
          }while(TIME_ELAPSED<1);
 
-       free(buf);
+       Inet_Forge_packet_destroy( recvpck.buf );
        Inet_CloseRawSock(sock);
        Inet_Restore_ifr();
    }
@@ -967,7 +968,7 @@ int Inet_CheckSwitch()
    {
        int  sourceip,destip,sock,MTU;
        char MyMAC[6],DestMAC[6],SourceMAC[6];
-       char *buf;
+       struct recv_packet recvpck;
        TIME_DECLARE;
 
        sourceip=inet_addr(Host_In_LAN[2].ip);
@@ -975,32 +976,34 @@ int Inet_CheckSwitch()
        Inet_GetMACfromString(Host_In_LAN[2].mac, SourceMAC);
        Inet_GetMACfromString(Host_In_LAN[1].mac, DestMAC);
        sock = Inet_OpenRawSock(Options.netiface);
-       fcntl(sock, F_SETFL, O_NONBLOCK);
+       Inet_SetNonBlock(sock);
        Inet_GetIfaceInfo(Options.netiface, &MTU, MyMAC, NULL, NULL);
        Inet_SetPromisc(Options.netiface);
 
-       buf = Inet_Forge_packet(MTU);
-       Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_IP );
-       Inet_Forge_ip( buf + ETH_HEADER,
+       recvpck.buf = Inet_Forge_packet( ALIGN_ETH_TO_WORD + MTU);
+       recvpck.aligned = recvpck.buf + ALIGN_ETH_TO_WORD;
+       
+       Inet_Forge_ethernet( recvpck.aligned, MyMAC, DestMAC, ETH_P_IP );
+       Inet_Forge_ip( recvpck.aligned + ETH_HEADER,
                       sourceip, destip,
                       sizeof(ICMP_header),
                       0xe77e, 0,
                       IPPROTO_ICMP );
-       Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
-       Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+       Inet_Forge_icmp( recvpck.aligned + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+       Inet_SendRawPacket(sock, recvpck.aligned, ETH_HEADER + IP_HEADER + ICMP_HEADER);
 
        TIME_START;
        do
        {
            short type; int len;
 
-           len=Inet_GetRawPacket(sock,buf,MTU,&type);
+           len=Inet_GetRawPacket(sock, recvpck.aligned, MTU, &type);
            TIME_FINISH;
 
             if (len>0)
             {
                ETH_header *eth;
-               eth=(ETH_header *)buf;
+               eth=(ETH_header *) recvpck.aligned;
                if (!memcmp(SourceMAC,eth->dest_mac,6))
                {
                   link_type=1;
@@ -1009,7 +1012,7 @@ int Inet_CheckSwitch()
             }
          }while(TIME_ELAPSED<1);
 
-       free(buf);
+       Inet_Forge_packet_destroy( recvpck.buf );
        Inet_CloseRawSock(sock);
        Inet_Restore_ifr();
    }
