@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_passive.c,v 1.24 2002/04/18 17:03:17 alor Exp $
+    $Id: ec_interface_passive.c,v 1.27 2002/05/31 16:50:14 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -703,8 +703,6 @@ void Interface_Passive_Run(void)
 {
    int KeyPress;
    pthread_t Dryad_pid;
-   u_short passlist_csum = 0;
-   u_short hash = 0;
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
    struct pollfd poll_fd;
 #else
@@ -769,11 +767,9 @@ void Interface_Passive_Run(void)
    loop
    {
 
-      hash = Inet_Forge_Checksum((u_short *)Passive_Host, 0xe77e, sizeof(PASSIVE_DATA)*number_of_passive_hosts, 0, 0);
-
-      if (passlist_csum != hash && number_of_passive_hosts > 0) {    // check if the list has changed by calculating its checksum
+      if (pass_list_modified) {
          Interface_Passive_InitList();
-         passlist_csum = hash;
+         pass_list_modified = 0;
       }
 
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
@@ -874,6 +870,7 @@ void Interface_Passive_Run(void)
                      Decodedata_FreePassiveList();
                      number_of_passive_hosts = -1;
                      Host_Pointer = 0;
+                     Host_Base_Pointer = 0;
                      showname = 0;
                      Options.passive = 0;
                      read_from_dump_flag = 0;  // permit a new scan of the offline file
