@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_sniff.c,v 1.25 2002/04/18 17:39:10 alor Exp $
+    $Id: ec_interface_sniff.c,v 1.27 2002/04/30 14:49:38 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -47,7 +47,6 @@
 #include "include/ec_doppleganger.h"
 #include "include/ec_grell.h"
 #include "include/ec_inet.h"
-#include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_buffer.h"
 #include "include/ec_logtofile.h"
@@ -387,8 +386,6 @@ void Interface_Sniff_Run(short mode)
    #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
       pthread_t Grell_pid = 0;
    #endif
-   u_short connlist_csum = 0;
-   u_short hash = 0;
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
    struct pollfd poll_fd;
 #else
@@ -471,11 +468,9 @@ void Interface_Sniff_Run(short mode)
 
    loop
    {
-      hash = Inet_Forge_Checksum((u_short *)Conn_Between_Hosts, 0xe77e, sizeof(CONNECTION)*number_of_connections, 0, 0);
-
-      if (connlist_csum != hash && number_of_connections > 0) {   // check if the list has changed by calculating its checksum
+      if (conn_list_modified) {
          Interface_Sniff_InitList();
-         connlist_csum = hash;
+         conn_list_modified = 0;
       }
 
 #ifdef PERMIT_PLUGINS
@@ -744,7 +739,6 @@ void Interface_Sniff_Run(short mode)
 }
 
 
-
 #endif
 
 /* EOF */
