@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_sniff_data.c,v 1.16 2002/04/18 17:03:17 alor Exp $
+    $Id: ec_interface_sniff_data.c,v 1.19 2002/06/25 07:38:12 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -32,9 +32,9 @@
 
 #include <sys/types.h>
 #if defined(HAVE_SYS_POLL_H)
-	#include <sys/poll.h>
+   #include <sys/poll.h>
 #elif defined (HAVE_POLL_H)
-	#include <poll.h>
+   #include <poll.h>
 #endif
 
 #include "include/ec_interface.h"
@@ -45,6 +45,8 @@
 #include "include/ec_illithid.h"
 #include "include/ec_buffer.h"
 #include "include/ec_inet_structures.h"
+#include "include/ec_binder.h"
+#include "include/ec_thread.h"
 
 #define PAD_BUFFER 1000        // buffered lines for sniffing
 
@@ -80,6 +82,8 @@ void Interface_Sniff_Data_Scroll(short direction);
 void Interface_Sniff_Data_DrawScroller(void);
 void Interface_Sniff_Data_Inject(char proto, char *app);
 void Interface_Sniff_Data_Kill(char proto);
+void Interface_Sniff_Data_Bind(char proto, char *ipsource, char *ipdest);
+u_short Interface_Sniff_Data_WaitPort(void);
 
 // global variables
 
@@ -111,6 +115,8 @@ char ipdest[16];
 u_short portsource;
 u_short portdest;
 
+pthread_t Binder_pid=0;
+
 //---------------------------
 
 void Interface_Sniff_Data_Winch(void)  // TODO better handling...
@@ -231,19 +237,31 @@ void Interface_Sniff_Data_LogToFile(char proto)
    if (joined)
    {
       strcpy(question, "Do you want to log the trafic to this file ? (y/n)");
+#ifdef CYGWIN      
+      snprintf(filename, sizeof(filename), "%s-%c-%s[%d]-%s[%d]-FULL.log", date, proto, ipsource, portsource, ipdest, portdest);
+#else
       snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d-FULL.log", date, proto, ipsource, portsource, ipdest, portdest);
+#endif
    }
    else
    {
       if (win_pointer == data_source_win)
       {
          strcpy(question, "Do you want to log SOURCE-to-DEST to this file ? (y/n)");
+#ifdef CYGWIN      
+         snprintf(filename, sizeof(filename), "%s-%c-%s[%d]-%s[%d].log", date, proto, ipsource, portsource, ipdest, portdest);
+#else
          snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipsource, portsource, ipdest, portdest);
+#endif
       }
       else
       {
          strcpy(question, "Do you want to log DEST-to-SOURCE to this file ? (y/n)");
+#ifdef CYGWIN      
+         snprintf(filename, sizeof(filename), "%s-%c-%s[%d]-%s[%d].log", date, proto, ipdest, portdest, ipsource, portsource);
+#else
          snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipdest, portdest, ipsource, portsource);
+#endif
       }
    }
 
@@ -532,6 +550,9 @@ void Interface_Sniff_Data_SniffData(void)
        return;
    }
 
+   if (binder_pipe != -1 && Binder_pid)
+       Buffer_Put(binder_pipe, &data_from_illithid, sizeof(SNIFFED_DATA));
+
    if (joined)
    {
       if (log_joined) { write(fileno(file_joined), &data_from_illithid.data, data_from_illithid.datasize); fflush(file_joined);}
@@ -656,7 +677,7 @@ void Interface_Sniff_Data_DrawScroller(void)
 
    if (joined)
    {
-   	wmove(data_joined_win, 1, W_MAINX2 - 5);
+      wmove(data_joined_win, 1, W_MAINX2 - 5);
       wvline(data_joined_win, ACS_VLINE, W_MAINY2-10);
       wattron(data_joined_win, A_REVERSE);
       wmove(data_joined_win, jvpos, W_MAINX2 - 5);
@@ -666,7 +687,7 @@ void Interface_Sniff_Data_DrawScroller(void)
    }
    else
    {
-   	wmove(data_source_win, 1, W_MAINX2 / 2 - 3);
+      wmove(data_source_win, 1, W_MAINX2 / 2 - 3);
       wvline(data_source_win, ACS_VLINE, W_MAINY2-10);
       wattron(data_source_win, A_REVERSE);
       wmove(data_source_win, svpos, W_MAINX2 / 2 - 3);
@@ -674,7 +695,7 @@ void Interface_Sniff_Data_DrawScroller(void)
       wnoutrefresh(data_source_win);
       wattroff(data_source_win, A_REVERSE);
 
-		wmove(data_dest_win, 1, W_MAINX2 / 2 - 3);
+      wmove(data_dest_win, 1, W_MAINX2 / 2 - 3);
       wvline(data_dest_win, ACS_VLINE, W_MAINY2-10);
       wattron(data_dest_win, A_REVERSE);
       wmove(data_dest_win, dvpos, W_MAINX2 / 2 - 3);
@@ -813,6 +834,46 @@ void Interface_Sniff_Data_Kill(char proto)
 
 }
 
+u_short Interface_Sniff_Data_WaitPort(void)
+{
+   while(Global_Binder_Port==0)
+      usleep(500);
+   return (Global_Binder_Port);
+}
+
+void Interface_Sniff_Data_Bind(char proto, char *ipsource, char *ipdest)
+{
+   u_long s_ip, d_ip;
+                     
+   if (joined) {
+      Interface_PopUp("Can't bind while in joined view");
+      return;
+   }
+           
+   if (proto != 'T') {
+      Interface_PopUp("You can only bind TCP connections");
+      return;
+   }
+           
+   if (binder_pipe == -1)
+      binder_pipe = Buffer_Create(1.0e6);
+           
+   s_ip = inet_addr(ipsource);
+   d_ip = inet_addr(ipdest);
+               
+   if (Binder_pid) ECThread_destroy(Binder_pid); 
+   
+   Global_Binder_Port = 0;
+         
+   if (win_pointer != data_source_win) { 
+           Binder_pid = Binder_Start(s_ip, d_ip, portsource, portdest, proto);
+      Interface_PopUp("Binded Connection D-to-S on port %d", Interface_Sniff_Data_WaitPort());
+   } else {
+      Binder_pid = Binder_Start(d_ip, s_ip, portsource, portdest, proto);
+      Interface_PopUp("Binded Connection S-to-D on port %d", Interface_Sniff_Data_WaitPort());
+   }
+
+}
 
 
 
@@ -822,7 +883,7 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
    int dimY = W_MAINY2 - W_MAINY1 - 3;
    int dimX = W_MAINX2 / 2 - 2;
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
-	struct pollfd poll_fd;
+   struct pollfd poll_fd;
 #else
    fd_set msk_fd;
    struct timeval TimeOut;
@@ -831,6 +892,7 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
    char macsource[20];
    char macdest[20];
    char app[18];
+   
 
    strlcpy(ipsource, ips, sizeof(ipsource));     // save locally because other threads can
    strlcpy(ipdest, ipd, sizeof(ipdest));         // realloc the array containing these values
@@ -1046,6 +1108,11 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
                      Interface_Sniff_Data_Redraw();
                      break;
 #endif
+            case 'B':
+            case 'b':
+                     Interface_Sniff_Data_Bind(proto, ipsource, ipdest);
+                     Interface_Sniff_Data_Redraw();
+                     break;
 
             case KEY_F(1):
             case 'H':
@@ -1067,6 +1134,7 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
                         "[jJ]      - join the two windows",
                         "[sS]      - stop/cont the sniff (only visualization)",
                         "[lL]      - Log to file",
+                        "[bB]      - Bind the sniffed data to a port",
                         NULL};
                         Interface_HelpWindow(help);
                      }
@@ -1079,6 +1147,8 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
                      if (log_dest) fclose(file_dest);
                      if (log_source) fclose(file_source);
                      if (log_joined) fclose(file_joined);
+                     if (Binder_pid) ECThread_destroy(Binder_pid);    
+                     Binder_pid = 0;
                      log_dest = log_source = log_joined = 0;
                      stop = 0;
                      inject_tod=0; inject_tos=0;  // reset counter
