@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_logtofile.c,v 1.12 2002/04/12 15:59:15 alor Exp $
+    $Id: ec_logtofile.c,v 1.17 2002/05/14 12:25:12 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -47,7 +47,7 @@ int LogToFile_AlreadyLogged(CONNECTION *data, char *filename)
    char line[100];
    int foo;
    char *p, *q;
-   char source[16], dest[16], type[15], user[30], pass[30];
+   char source[16], dest[16], type[15], user[50], pass[50];
 
    memset(line, 0, sizeof(line));
 
@@ -62,6 +62,8 @@ int LogToFile_AlreadyLogged(CONNECTION *data, char *filename)
       if( sscanf(line, "%d:%d:%d", &foo, &foo, &foo) == 3 ) {  // new connection is found
 
          strncpy(type, strrchr(line, ' ') + 1, 14 );
+         memset(source, 0, sizeof(source));
+         memset(dest, 0, sizeof(dest));
 
          p = line + 10;
          strncpy(source, strtok(p, ":"), 15);
@@ -150,7 +152,7 @@ void LogToFile(SNIFFED_DATA *data)
                         data->proto, data->source_ip, data->source_port, data->dest_ip, data->dest_port );
 #endif
 
-   fto = fopen(filename, "a");
+   fto = fopen(filename, "ab");
    if (fto == NULL)
       ERROR_MSG("fopen()");
 
@@ -215,7 +217,7 @@ void LogToFile_FilteredData(u_char * buf_ip)
 
    if (data && datalen)
    {
-      fto = fopen(logname, "a");
+      fto = fopen(logname, "ab");
       if (fto == NULL)
          ERROR_MSG("fopen()");
       write(fileno(fto), data, datalen);
@@ -233,10 +235,13 @@ char *LogToFile_DumpPass(void)
    int i;
    time_t tt = time(NULL);
    struct tm *dd = localtime(&tt);
+#ifdef DEBUG
+   int count = 0;
+#endif
 
    DEBUG_MSG("LogToFile_DumpPass");
 
-   snprintf(logname, sizeof(logname), "%04d%02d%02d-%02d%02d-Dumped_Password.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday, dd->tm_hour, dd->tm_min);
+   snprintf(logname, sizeof(logname), "%04d%02d%02d-Dumped_Password.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday);
 
    fto = fopen(logname, "a");
    if (fto == NULL)
@@ -257,9 +262,10 @@ char *LogToFile_DumpPass(void)
          if (strlen(Conn_Between_Hosts[i].info))
             fprintf(fto, "\n%s\n", Conn_Between_Hosts[i].info);
          fflush(fto);
-      }
-      else if (strlen(Conn_Between_Hosts[i].info))
-      {
+#ifdef DEBUG
+          count++;
+#endif
+      } else if (strlen(Conn_Between_Hosts[i].info)) {
          fprintf(fto, "\n\n%s:%d -> %s:%d\t\t%s\n\n", Conn_Between_Hosts[i].source_ip,
                                                       Conn_Between_Hosts[i].source_port,
                                                       Conn_Between_Hosts[i].dest_ip,
@@ -271,9 +277,17 @@ char *LogToFile_DumpPass(void)
          if (strlen(Conn_Between_Hosts[i].info))
             fprintf(fto, "\n%s\n", Conn_Between_Hosts[i].info);
          fflush(fto);
+#ifdef DEBUG
+          count++;
+#endif
       }
    }
-
+   
+#ifdef DEBUG
+   /* Mac os X will complain about the count var not declared... */
+   DEBUG_MSG("LogToFile_DumpPass -- %d passwords dumped", count);
+#endif
+   
    fclose(fto);
    return logname;
 }
@@ -294,9 +308,9 @@ char *LogToFile_MakePassiveReport(char mode)
    DEBUG_MSG("LogToFile_MakePassiveReport");
 
    if (mode == 'l')
-      snprintf(logname, sizeof(logname), "%04d%02d%02d-%02d%02d-Passive_Local_Report.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday, dd->tm_hour, dd->tm_min);
+      snprintf(logname, sizeof(logname), "%04d%02d%02d-Passive_Local_Report.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday);
    else if (mode == 'L')
-      snprintf(logname, sizeof(logname), "%04d%02d%02d-%02d%02d-Passive_Full_Report.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday, dd->tm_hour, dd->tm_min);
+      snprintf(logname, sizeof(logname), "%04d%02d%02d-Passive_Full_Report.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday);
 
    fto = fopen(logname, "a");
    if (fto == NULL)
