@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_main.c,v 1.30 2002/04/18 17:03:17 alor Exp $
+    $Id: ec_main.c,v 1.34 2002/06/27 17:27:37 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -62,8 +62,6 @@ CURRENT_SNIFFED_DATA current_illithid_data;
 HOST Host_Source;
 HOST Host_Dest;
 
-char **Host_List;          // scan only these hosts
-int host_to_be_scanned;
 
 char *Execute_Plugin;
 
@@ -119,8 +117,11 @@ int main(int argc, char *argv[])
    Options.delay = DEFAULT_DELAY;               // the default delay between arp replies (ec_doppleganger)
    Options.storm_delay = DEFAULT_STORM_DELAY;   // the default delay between arp request on start up (ec_inet)
 
-   fprintf (stdout, "\n\033[01m\033[1m%s %s (c) 2001 %s\033[0m\n\n", PROGRAM, VERSION, AUTHORS);
-
+#if DEVEL_RELEASE == 1
+   fprintf (stdout, "\n\033[01m\033[1m%s %s beta %s (c) 2002 %s\033[0m\n\n", PROGRAM, VERSION, RELEASE_DATE, AUTHORS);
+#else
+   fprintf (stdout, "\n\033[01m\033[1m%s %s (c) 2002 %s\033[0m\n\n", PROGRAM, VERSION, AUTHORS);
+#endif
    if (Parser_ParseOptions(argc, argv) == 1)    // config file
       Parser_ParseConfFile(optarg);
 
@@ -350,23 +351,11 @@ exit(0);
 
 void Main_CheckForRun(char *program_argv0)
 {
-#ifdef CYGWIN
-   #include <sys/utsname.h>
-   struct utsname buf;
-#endif
-
    int i;
 
 DEBUG_MSG("Main_CheckForRun -- [%s]", program_argv0);
 
-#ifdef CYGWIN
-
-   uname(&buf);
-
-   if (strncmp(strstr(buf.sysname, "_") + 1, "NT", 2))
-      Error_msg("Ettercap only runs on Windows NT / 2000 / XP");
-
-#else
+#ifndef CYGWIN
    if (getuid() != 0)
       Error_msg("Sorry UID %d, you must be root to run %s !!", getuid(), PROGRAM);
 #endif
