@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_packet.c,v 1.3 2002/03/17 23:40:49 alor Exp $
+    $Id: ec_packet.c,v 1.5 2002/05/04 09:38:21 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -80,6 +80,12 @@ int packet_create_object(struct packet_object **po, u_char *buf, int *len)
          (*po)->L3.options = (u_char *)(ip + 1);
 
       (*po)->L3.len = ntohs(ip->t_len) ;
+      
+      if ( (*po)->L3.len > *len - ETH_HEADER) {    /* unexpected len */
+         free(*po);
+         *po = NULL;
+         return -1;
+      }
    }
 
    (*po)->L4.header = (u_char *) ((int)ip + ip->h_len * 4);    /* default */
@@ -113,6 +119,12 @@ int packet_create_object(struct packet_object **po, u_char *buf, int *len)
       (*po)->L4.sport = &udp->source;
       (*po)->L4.dport = &udp->dest;
 
+      if ((*po)->L4.len > *len - ETH_HEADER - IP_HEADER) {    /* unexpected len */
+         free(*po);
+         *po = NULL;
+         return -1;
+      }
+      
       /* DATA level */
 
       (*po)->data.data = (char *)((int)udp + UDP_HEADER);
@@ -138,10 +150,16 @@ int packet_create_object(struct packet_object **po, u_char *buf, int *len)
 
       (*po)->L4.len = ntohs(ip->t_len) - (ip->h_len * 4);
 
+      if ((*po)->L4.len > *len - ETH_HEADER - IP_HEADER) {    /* unexpected len */
+         free(*po);
+         *po = NULL;
+         return -1;
+      }
+      
       /* DATA level */
 
       (*po)->data.data = (char *)((int)tcp + tcp->doff * 4);
-      (*po)->data.len = ntohs(ip->t_len) - (ip->h_len * 4) - (tcp->doff * 4);
+      (*po)->data.len = (*po)->L4.len - (tcp->doff * 4);
 
    }
 
