@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_signal.c,v 1.9 2002/03/28 14:54:54 alor Exp $
+    $Id: ec_signal.c,v 1.11 2002/05/17 13:12:33 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -43,13 +43,6 @@
    extern WINDOW *data_source_win;
    extern WINDOW *plugin_window;
 
-   #ifdef HAVE_TERMIOS_H
-      #ifdef CYGWIN
-         #undef FIONBIO
-      #endif
-      #include <termios.h>
-      extern struct termios original_term_info;
-   #endif
 #endif
 
 #include "include/ec_thread.h"
@@ -61,6 +54,11 @@ RETSIGTYPE Signal_SEGV(int sig);
 RETSIGTYPE Signal_TERM(int sig);
 RETSIGTYPE Signal_WINCH(int sig);
 
+#ifdef HAVE_TERMIOS_H
+   extern void reset_term(void);
+#endif
+
+
 //-----------------------
 
 void Signal_SigBuster(void)
@@ -159,9 +157,13 @@ RETSIGTYPE Signal_TERM(int sig)
    if (Options.onscreen)
       Interface_CloseScreen();
 #endif
+#ifdef HAVE_TERMIOS_H
+   if(!Options.quiet && !Options.onscreen)
+      reset_term();
+#endif  
 
    if (sig == SIGINT) {
-      fprintf(stderr, "\n\nUser requested a CTRL+C... (exiting gracefully)\n\n");
+      fprintf(stderr, "\n\nUser requested a CTRL+C... (deprecated, next time use 'q')\n\n");
    } else {
       #ifdef HAVE_STRSIGNAL
          fprintf(stderr, "\n\n Ettercap Signal handler... (caught SIGNAL: %d) | %s\n\n", sig, strsignal(sig));
@@ -170,7 +172,7 @@ RETSIGTYPE Signal_TERM(int sig)
       #endif
    }
 
-   signal(sig, SIG_DFL);
+   signal(sig, SIG_IGN);
 
    exit(1);
 
