@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_simple.c,v 1.32 2002/04/18 17:03:17 alor Exp $
+    $Id: ec_simple.c,v 1.36 2002/05/17 09:38:14 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -38,7 +38,6 @@
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_decodedata.h"
-#include "include/ec_dissector.h"
 #include "include/ec_illithid.h"
 #include "include/ec_doppleganger.h"
 #include "include/ec_grell.h"
@@ -161,8 +160,11 @@ void Simple_CreateCertFile(void)
    else
       wait(NULL);
 
-   fta = fopen(CERT_FILE, "a");
-   ftr = fopen(CERT_FILE ".new", "r");
+   if ( (fta = fopen(CERT_FILE, "a")) == NULL)
+      Error_msg("Certificate generation failed !!");
+   
+   if ( (ftr = fopen(CERT_FILE ".new", "r")) == NULL)
+      Error_msg("Certificate generation failed !!");
 
    while (fgets(line, sizeof(line), ftr))
       fprintf(fta, "%s", line);
@@ -428,7 +430,7 @@ void Simple_Run(void)
    char source[20], dest[20];
    char proto = 'A';       // default value
    char mode = IPBASED;    // defaulf value
-   struct in_addr addr;
+   //struct in_addr addr;
    TIME_DECLARE;
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
    struct pollfd poll_fd;
@@ -627,12 +629,12 @@ void Simple_Run(void)
    current_illithid_data.proto = proto;
    current_illithid_data.source_port = Host_Source.port;
    current_illithid_data.dest_port = Host_Dest.port;
-
+/*
    if (inet_aton(Host_Source.ip, &addr))
       current_illithid_data.source_ip = ntohl(addr.s_addr);
    if (inet_aton(Host_Dest.ip, &addr))
       current_illithid_data.dest_ip =  ntohl(addr.s_addr);
-
+*/
    TIME_START;
 
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
@@ -887,7 +889,6 @@ void Simple_PassiveScan(void)
    pthread_t Dryad_pid;
    int i;
    TIME_DECLARE;
-   u_short passive_csum=0;
 #if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
    struct pollfd poll_fd;
 #else
@@ -1049,11 +1050,9 @@ void Simple_PassiveScan(void)
          }
 
 
-         if (Options.logtofile)
-         {
+         if (Options.logtofile) {
             TIME_FINISH;
-            if (TIME_ELAPSED >= 300)
-            {
+            if (TIME_ELAPSED >= 300) {
                DEBUG_MSG("\tCollected infos saved after %.0f minutes...", (TIME_ELAPSED)/60);
                if (!Options.quiet) printf("\tCollected infos saved after %.0f minutes..." ,(TIME_ELAPSED)/60);
                TIME_START;                       // after 300 seconds (5 min)...
@@ -1061,12 +1060,8 @@ void Simple_PassiveScan(void)
             }
          }
 
-         if (!Options.quiet)
-         {
-            u_short hash = Inet_Forge_Checksum((u_short *)Passive_Host, 0xe77e, sizeof(PASSIVE_DATA)*number_of_passive_hosts, 0, 0);
-
-            if (passive_csum != hash && number_of_passive_hosts > 0)
-            {
+         if (!Options.quiet) {
+            if (pass_list_modified) {
                int j;
 
                Decodedata_Passive_SortList();
@@ -1075,7 +1070,7 @@ void Simple_PassiveScan(void)
                {
                   printf(" --> %15s : %2s : %s\n", Passive_Host[j].ip, Passive_Host[j].type, Passive_Host[j].os);
                }
-               passive_csum = hash;
+               pass_list_modified = 0;
             }
          }
          usleep(1);
