@@ -20,6 +20,9 @@ extern char * Decodedata_TCPFlags(char flags);
 extern void Decodedata_ConvertPassiveToHost(void);
 extern void Decodedata_Passive_SortList(void);
 
+extern int conn_list_modified;   /* use these flags to refresh the interfaces */
+extern int pass_list_modified;
+
 #endif
 
 /* EOF */
