@@ -56,11 +56,14 @@ extern int Dissector_base64decode(char *bufplain, const char *bufcoded);
 #define ONLY_CONNECTION {}
 #define DATA_DISSECTOR  {}
 
+#define CREATE_VIRTUAL_BUFFER(x)    vbuf_p x; \
+                                    vbuf_create(&x, po->data.data, po->data.len); 
 
-#define PREPARE_VIRTUAL_BUFFER   { \
-                                    vbuf_p vbuf; \
-                                    vbuf_create(&vbuf, po->data.data, po->data.len); \
-                                 }
+#define CREATE_VIRTUAL_BUFFER_DUP(x,y)    vbuf_p x; \
+                                          char *y; \
+                                          int y_len; \
+                                          y_len = packet_duplicate(po, LEVEL_DATA, &y); \
+                                          vbuf_create(&x, y, y_len); 
 
 
 // dissectors....
