@@ -1,5 +1,5 @@
 
-/* $Id: ec_main.h,v 1.43 2002/04/22 19:43:44 alor Exp $ */
+/* $Id: ec_main.h,v 1.60 2002/06/27 18:58:51 alor Exp $ */
 
 
 #if !defined(EC_MAIN_H)
@@ -10,14 +10,22 @@
    #include <config.h>     // autoheader   -I.
 #endif
 
-#define DEVEL_RELEASE   0 
-#define RELEASE_DATE    "20020422"
-#define VERSION         "0.6.5"
+#define DEVEL_RELEASE   0
+#define RELEASE_DATE    "20020702"
+#define VERSION         "0.6.7"
 #define PROGRAM         "ettercap"
 #define AUTHORS         "ALoR & NaGA"
 
 #define loop for(;;)
 
+#ifdef CYGWIN
+   #include <windows.h>
+   #include <winsock2.h> // this include must be the first !! cygwin sux !
+#else
+   #include <sys/types.h>
+   #include <sys/time.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #if defined (LINUX) && !defined (__USE_GNU)  // for memmem(), strsignal(), etc etc...
@@ -28,13 +36,6 @@
    #undef __USE_GNU
 #endif
 #include <strings.h>
-#ifdef CYGWIN
-   #include <windows.h>
-   #include <winsock2.h>
-#else
-   #include <sys/types.h>
-   #include <sys/time.h>
-#endif
 #include <unistd.h>
 #include <time.h>
 #include <pthread.h>
@@ -65,7 +66,7 @@
    #include "../missing/scandir.h"
 #endif
 
-#if defined (MACOSX) || defined (CYGWIN)
+#if defined (CYGWIN)
    #define exit_func(x) atexit((void (*)(void))x)
    #define exit_func_end()
 #else
@@ -329,9 +330,6 @@ int gettimeofday(struct timeval *__p, struct timezone *__z);
 #endif
 
 
-extern char **Host_List;
-extern int host_to_be_scanned;
-
 #define DEFAULT_DELAY 30            // in seconds, delay between arp replies
 #define DEFAULT_STORM_DELAY 1500    // in microseconds, delay between inizial arp request
 
